dedalus

package module
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 10, 2026 License: MIT Imports: 19 Imported by: 2

README

Dedalus Go API Library

Go Reference

The Dedalus Go library provides convenient access to the Dedalus REST API from applications written in Go.

It is generated with Stainless.

MCP Server

Use the Dedalus MCP Server to enable AI assistants to interact with this API, allowing them to explore endpoints, make test requests, and use documentation to help integrate this SDK into your application.

Add to Cursor Install in VS Code

Note: You may need to set environment variables in your MCP client.

Installation

import (
	"github.com/dedalus-labs/dedalus-go" // imported as dedalus
)

Or to pin the version:

go get -u 'github.com/dedalus-labs/dedalus-go@v0.5.0'

Requirements

This library requires Go 1.22+.

Usage

The full API of this library can be found in api.md.

package main

import (
	"context"
	"fmt"

	"github.com/dedalus-labs/dedalus-go"
	"github.com/dedalus-labs/dedalus-go/option"
)

func main() {
	client := dedalus.NewClient(
		option.WithAPIKey("My API Key"), // defaults to os.LookupEnv("DEDALUS_API_KEY")
	)
	machine, err := client.Machines.New(context.TODO(), dedalus.MachineNewParams{
		CreateParams: dedalus.CreateParams{},
	})
	if err != nil {
		panic(err.Error())
	}
	fmt.Printf("%+v\n", machine.MachineID)
}

Request fields

The dedalus library uses the omitzero semantics from the Go 1.24+ encoding/json release for request fields.

Required primitive fields (int64, string, etc.) feature the tag `api:"required"`. These fields are always serialized, even their zero values.

Optional primitive types are wrapped in a param.Opt[T]. These fields can be set with the provided constructors, dedalus.String(string), dedalus.Int(int64), etc.

Any param.Opt[T], map, slice, struct or string enum uses the tag `json:"...,omitzero"`. Its zero value is considered omitted.

The param.IsOmitted(any) function can confirm the presence of any omitzero field.

p := dedalus.ExampleParams{
	ID:   "id_xxx",              // required property
	Name: dedalus.String("..."), // optional property

	Point: dedalus.Point{
		X: 0,              // required field will serialize as 0
		Y: dedalus.Int(1), // optional field will serialize as 1
		// ... omitted non-required fields will not be serialized
	},

	Origin: dedalus.Origin{}, // the zero value of [Origin] is considered omitted
}

To send null instead of a param.Opt[T], use param.Null[T](). To send null instead of a struct T, use param.NullStruct[T]().

p.Name = param.Null[string]()       // 'null' instead of string
p.Point = param.NullStruct[Point]() // 'null' instead of struct

param.IsNull(p.Name)  // true
param.IsNull(p.Point) // true

Request structs contain a .SetExtraFields(map[string]any) method which can send non-conforming fields in the request body. Extra fields overwrite any struct fields with a matching key. For security reasons, only use SetExtraFields with trusted data.

To send a custom value instead of a struct, use param.Override[T](value).

// In cases where the API specifies a given type,
// but you want to send something else, use [SetExtraFields]:
p.SetExtraFields(map[string]any{
	"x": 0.01, // send "x" as a float instead of int
})

// Send a number instead of an object
custom := param.Override[dedalus.FooParams](12)
Request unions

Unions are represented as a struct with fields prefixed by "Of" for each of its variants, only one field can be non-zero. The non-zero field will be serialized.

Sub-properties of the union can be accessed via methods on the union struct. These methods return a mutable pointer to the underlying data, if present.

// Only one field can be non-zero, use param.IsOmitted() to check if a field is set
type AnimalUnionParam struct {
	OfCat *Cat `json:",omitzero,inline`
	OfDog *Dog `json:",omitzero,inline`
}

animal := AnimalUnionParam{
	OfCat: &Cat{
		Name: "Whiskers",
		Owner: PersonParam{
			Address: AddressParam{Street: "3333 Coyote Hill Rd", Zip: 0},
		},
	},
}

// Mutating a field
if address := animal.GetOwner().GetAddress(); address != nil {
	address.ZipCode = 94304
}
Response objects

All fields in response structs are ordinary value types (not pointers or wrappers). Response structs also include a special JSON field containing metadata about each property.

type Animal struct {
	Name   string `json:"name,nullable"`
	Owners int    `json:"owners"`
	Age    int    `json:"age"`
	JSON   struct {
		Name        respjson.Field
		Owner       respjson.Field
		Age         respjson.Field
		ExtraFields map[string]respjson.Field
	} `json:"-"`
}

To handle optional data, use the .Valid() method on the JSON field. .Valid() returns true if a field is not null, not present, or couldn't be marshaled.

If .Valid() is false, the corresponding field will simply be its zero value.

raw := `{"owners": 1, "name": null}`

var res Animal
json.Unmarshal([]byte(raw), &res)

// Accessing regular fields

res.Owners // 1
res.Name   // ""
res.Age    // 0

// Optional field checks

res.JSON.Owners.Valid() // true
res.JSON.Name.Valid()   // false
res.JSON.Age.Valid()    // false

// Raw JSON values

res.JSON.Owners.Raw()                  // "1"
res.JSON.Name.Raw() == "null"          // true
res.JSON.Name.Raw() == respjson.Null   // true
res.JSON.Age.Raw() == ""               // true
res.JSON.Age.Raw() == respjson.Omitted // true

These .JSON structs also include an ExtraFields map containing any properties in the json response that were not specified in the struct. This can be useful for API features not yet present in the SDK.

body := res.JSON.ExtraFields["my_unexpected_field"].Raw()
Response Unions

In responses, unions are represented by a flattened struct containing all possible fields from each of the object variants. To convert it to a variant use the .AsFooVariant() method or the .AsAny() method if present.

If a response value union contains primitive values, primitive fields will be alongside the properties but prefixed with Of and feature the tag json:"...,inline".

type AnimalUnion struct {
	// From variants [Dog], [Cat]
	Owner Person `json:"owner"`
	// From variant [Dog]
	DogBreed string `json:"dog_breed"`
	// From variant [Cat]
	CatBreed string `json:"cat_breed"`
	// ...

	JSON struct {
		Owner respjson.Field
		// ...
	} `json:"-"`
}

// If animal variant
if animal.Owner.Address.ZipCode == "" {
	panic("missing zip code")
}

// Switch on the variant
switch variant := animal.AsAny().(type) {
case Dog:
case Cat:
default:
	panic("unexpected type")
}
RequestOptions

This library uses the functional options pattern. Functions defined in the option package return a RequestOption, which is a closure that mutates a RequestConfig. These options can be supplied to the client or at individual requests. For example:

client := dedalus.NewClient(
	// Adds a header to every request made by the client
	option.WithHeader("X-Some-Header", "custom_header_info"),
)

client.Machines.New(context.TODO(), ...,
	// Override the header
	option.WithHeader("X-Some-Header", "some_other_custom_header_info"),
	// Add an undocumented field to the request body, using sjson syntax
	option.WithJSONSet("some.json.path", map[string]string{"my": "object"}),
)

The request option option.WithDebugLog(nil) may be helpful while debugging.

See the full list of request options.

Pagination

This library provides some conveniences for working with paginated list endpoints.

You can use .ListAutoPaging() methods to iterate through items across all pages:

iter := client.Machines.ListAutoPaging(context.TODO(), dedalus.MachineListParams{})
// Automatically fetches more pages as needed.
for iter.Next() {
	machineListItem := iter.Current()
	fmt.Printf("%+v\n", machineListItem)
}
if err := iter.Err(); err != nil {
	panic(err.Error())
}

Or you can use simple .List() methods to fetch a single page and receive a standard response object with additional helper methods like .GetNextPage(), e.g.:

page, err := client.Machines.List(context.TODO(), dedalus.MachineListParams{})
for page != nil {
	for _, machine := range page.Items {
		fmt.Printf("%+v\n", machine)
	}
	page, err = page.GetNextPage()
}
if err != nil {
	panic(err.Error())
}
Errors

When the API returns a non-success status code, we return an error with type *dedalus.Error. This contains the StatusCode, *http.Request, and *http.Response values of the request, as well as the JSON of the error body (much like other response objects in the SDK).

To handle errors, we recommend that you use the errors.As pattern:

_, err := client.Machines.New(context.TODO(), dedalus.MachineNewParams{
	CreateParams: dedalus.CreateParams{},
})
if err != nil {
	var apierr *dedalus.Error
	if errors.As(err, &apierr) {
		println(string(apierr.DumpRequest(true)))  // Prints the serialized HTTP request
		println(string(apierr.DumpResponse(true))) // Prints the serialized HTTP response
		println(apierr.ErrorCode)                  // IDEMPOTENCY_KEY_REUSED
		println(apierr.Message)                    // idempotency key reused with different request parameters
		println(apierr.Retryable)                  // false
	}
	panic(err.Error()) // GET "/v1/machines": 400 Bad Request { ... }
}

When other errors occur, they are returned unwrapped; for example, if HTTP transport fails, you might receive *url.Error wrapping *net.OpError.

Timeouts

Requests do not time out by default; use context to configure a timeout for a request lifecycle.

Note that if a request is retried, the context timeout does not start over. To set a per-retry timeout, use option.WithRequestTimeout().

// This sets the timeout for the request, including all the retries.
ctx, cancel := context.WithTimeout(context.Background(), 5*time.Minute)
defer cancel()
client.Machines.New(
	ctx,
	dedalus.MachineNewParams{
		CreateParams: dedalus.CreateParams{},
	},
	// This sets the per-retry timeout
	option.WithRequestTimeout(20*time.Second),
)
File uploads

Request parameters that correspond to file uploads in multipart requests are typed as io.Reader. The contents of the io.Reader will by default be sent as a multipart form part with the file name of "anonymous_file" and content-type of "application/octet-stream".

The file name and content-type can be customized by implementing Name() string or ContentType() string on the run-time type of io.Reader. Note that os.File implements Name() string, so a file returned by os.Open will be sent with the file name on disk.

We also provide a helper dedalus.File(reader io.Reader, filename string, contentType string) which can be used to wrap any io.Reader with the appropriate file name and content type.

Retries

Certain errors will be automatically retried 2 times by default, with a short exponential backoff. We retry by default all connection errors, 408 Request Timeout, 409 Conflict, 429 Rate Limit, and >=500 Internal errors.

You can use the WithMaxRetries option to configure or disable this:

// Configure the default for all requests:
client := dedalus.NewClient(
	option.WithMaxRetries(0), // default is 2
)

// Override per-request:
client.Machines.New(
	context.TODO(),
	dedalus.MachineNewParams{
		CreateParams: dedalus.CreateParams{},
	},
	option.WithMaxRetries(5),
)
Accessing raw response data (e.g. response headers)

You can access the raw HTTP response data by using the option.WithResponseInto() request option. This is useful when you need to examine response headers, status codes, or other details.

// Create a variable to store the HTTP response
var response *http.Response
machine, err := client.Machines.New(
	context.TODO(),
	dedalus.MachineNewParams{
		CreateParams: dedalus.CreateParams{},
	},
	option.WithResponseInto(&response),
)
if err != nil {
	// handle error
}
fmt.Printf("%+v\n", machine)

fmt.Printf("Status Code: %d\n", response.StatusCode)
fmt.Printf("Headers: %+#v\n", response.Header)
Making custom/undocumented requests

This library is typed for convenient access to the documented API. If you need to access undocumented endpoints, params, or response properties, the library can still be used.

Undocumented endpoints

To make requests to undocumented endpoints, you can use client.Get, client.Post, and other HTTP verbs. RequestOptions on the client, such as retries, will be respected when making these requests.

var (
    // params can be an io.Reader, a []byte, an encoding/json serializable object,
    // or a "…Params" struct defined in this library.
    params map[string]any

    // result can be an []byte, *http.Response, a encoding/json deserializable object,
    // or a model defined in this library.
    result *http.Response
)
err := client.Post(context.Background(), "/unspecified", params, &result)
if err != nil {
    …
}
Undocumented request params

To make requests using undocumented parameters, you may use either the option.WithQuerySet() or the option.WithJSONSet() methods.

params := FooNewParams{
    ID:   "id_xxxx",
    Data: FooNewParamsData{
        FirstName: dedalus.String("John"),
    },
}
client.Foo.New(context.Background(), params, option.WithJSONSet("data.last_name", "Doe"))
Undocumented response properties

To access undocumented response properties, you may either access the raw JSON of the response as a string with result.JSON.RawJSON(), or get the raw JSON of a particular field on the result with result.JSON.Foo.Raw().

Any fields that are not present on the response struct will be saved and can be accessed by result.JSON.ExtraFields() which returns the extra fields as a map[string]Field.

Middleware

We provide option.WithMiddleware which applies the given middleware to requests.

func Logger(req *http.Request, next option.MiddlewareNext) (res *http.Response, err error) {
	// Before the request
	start := time.Now()
	LogReq(req)

	// Forward the request to the next handler
	res, err = next(req)

	// Handle stuff after the request
	end := time.Now()
	LogRes(res, err, start - end)

    return res, err
}

client := dedalus.NewClient(
	option.WithMiddleware(Logger),
)

When multiple middlewares are provided as variadic arguments, the middlewares are applied left to right. If option.WithMiddleware is given multiple times, for example first in the client then the method, the middleware in the client will run first and the middleware given in the method will run next.

You may also replace the default http.Client with option.WithHTTPClient(client). Only one http client is accepted (this overwrites any previous client) and receives requests after any middleware has been applied.

Semantic versioning

This package generally follows SemVer conventions, though certain backwards-incompatible changes may be released as minor versions:

  1. Changes to library internals which are technically public but not intended or documented for external use. (Please open a GitHub issue to let us know if you are relying on such internals.)
  2. Changes that we do not expect to impact the vast majority of users in practice.

We take backwards-compatibility seriously and work hard to ensure you can rely on a smooth upgrade experience.

We are keen for your feedback; please open an issue with questions, bugs, or suggestions.

Contributing

See the contributing documentation.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Bool

func Bool(b bool) param.Opt[bool]

func BoolPtr

func BoolPtr(v bool) *bool

func DefaultClientOptions

func DefaultClientOptions() []option.RequestOption

DefaultClientOptions read from the environment (DEDALUS_API_KEY, DEDALUS_X_API_KEY, DEDALUS_ORG_ID, DEDALUS_BASE_URL). This should be used to initialize new clients.

func File

func File(rdr io.Reader, filename string, contentType string) file

func Float

func Float(f float64) param.Opt[float64]

func FloatPtr

func FloatPtr(v float64) *float64

func Int

func Int(i int64) param.Opt[int64]

func IntPtr

func IntPtr(v int64) *int64

func Opt

func Opt[T comparable](v T) param.Opt[T]

func Ptr

func Ptr[T any](v T) *T

func String

func String(s string) param.Opt[string]

func StringPtr

func StringPtr(v string) *string

func Time

func Time(t time.Time) param.Opt[time.Time]

func TimePtr

func TimePtr(v time.Time) *time.Time

Types

type ArtifactRef

type ArtifactRef struct {
	ArtifactID string `json:"artifact_id" api:"required"`
	Name       string `json:"name" api:"required"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		ArtifactID  respjson.Field
		Name        respjson.Field
		ExtraFields map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (ArtifactRef) RawJSON

func (r ArtifactRef) RawJSON() string

Returns the unmodified JSON received from the API

func (*ArtifactRef) UnmarshalJSON

func (r *ArtifactRef) UnmarshalJSON(data []byte) error

type Client

type Client struct {
	Options  []option.RequestOption
	Machines MachineService
}

Client creates a struct with services and top level methods that help with interacting with the Dedalus API. You should not instantiate this client directly, and instead use the NewClient method instead.

func NewClient

func NewClient(opts ...option.RequestOption) (r Client)

NewClient generates a new client with the default option read from the environment (DEDALUS_API_KEY, DEDALUS_X_API_KEY, DEDALUS_ORG_ID, DEDALUS_BASE_URL). The option passed in as arguments are applied after these default arguments, and all option will be passed down to the services and requests that this client makes.

func (*Client) Delete

func (r *Client) Delete(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error

Delete makes a DELETE request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Execute

func (r *Client) Execute(ctx context.Context, method string, path string, params any, res any, opts ...option.RequestOption) error

Execute makes a request with the given context, method, URL, request params, response, and request options. This is useful for hitting undocumented endpoints while retaining the base URL, auth, retries, and other options from the client.

If a byte slice or an io.Reader is supplied to params, it will be used as-is for the request body.

The params is by default serialized into the body using encoding/json. If your type implements a MarshalJSON function, it will be used instead to serialize the request. If a URLQuery method is implemented, the returned url.Values will be used as query strings to the url.

If your params struct uses param.Field, you must provide either [MarshalJSON], [URLQuery], and/or [MarshalForm] functions. It is undefined behavior to use a struct uses param.Field without specifying how it is serialized.

Any "…Params" object defined in this library can be used as the request argument. Note that 'path' arguments will not be forwarded into the url.

The response body will be deserialized into the res variable, depending on its type:

  • A pointer to a *http.Response is populated by the raw response.
  • A pointer to a byte array will be populated with the contents of the request body.
  • A pointer to any other type uses this library's default JSON decoding, which respects UnmarshalJSON if it is defined on the type.
  • A nil value will not read the response body.

For even greater flexibility, see option.WithResponseInto and option.WithResponseBodyInto.

func (*Client) Get

func (r *Client) Get(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error

Get makes a GET request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Patch

func (r *Client) Patch(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error

Patch makes a PATCH request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Post

func (r *Client) Post(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error

Post makes a POST request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Put

func (r *Client) Put(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error

Put makes a PUT request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

type CreateParams

type CreateParams struct {
	// Idle window before autosleep. Accepts fixed duration units like 30s, 30m, 2h,
	// 7d3h4s, or 1w3d, raw seconds ("1800"), or never to disable.
	Autosleep param.Opt[string] `json:"autosleep,omitzero"`
	// Memory in MiB.
	MemoryMiB param.Opt[int64] `json:"memory_mib,omitzero"`
	// Storage in GiB.
	StorageGiB param.Opt[int64] `json:"storage_gib,omitzero"`
	// CPU in vCPUs.
	VCPU param.Opt[float64] `json:"vcpu,omitzero"`
	// contains filtered or unexported fields
}

func (CreateParams) MarshalJSON

func (r CreateParams) MarshalJSON() (data []byte, err error)

func (*CreateParams) UnmarshalJSON

func (r *CreateParams) UnmarshalJSON(data []byte) error

type Error

type Error = apierror.Error

type Execution

type Execution struct {
	Command     []string  `json:"command" api:"required"`
	CreatedAt   time.Time `json:"created_at" api:"required" format:"date-time"`
	ExecutionID string    `json:"execution_id" api:"required"`
	MachineID   string    `json:"machine_id" api:"required"`
	// Any of "wake_in_progress", "queued", "running", "succeeded", "failed",
	// "cancelled", "expired".
	Status          ExecutionStatus `json:"status" api:"required"`
	Artifacts       []ArtifactRef   `json:"artifacts" api:"nullable"`
	CompletedAt     time.Time       `json:"completed_at" format:"date-time"`
	Cwd             string          `json:"cwd"`
	EnvKeys         []string        `json:"env_keys" api:"nullable"`
	ErrorCode       string          `json:"error_code"`
	ErrorMessage    string          `json:"error_message"`
	ExitCode        int64           `json:"exit_code"`
	ExpiresAt       time.Time       `json:"expires_at" format:"date-time"`
	RetryAfterMs    int64           `json:"retry_after_ms"`
	Signal          int64           `json:"signal"`
	StartedAt       time.Time       `json:"started_at" format:"date-time"`
	StderrBytes     int64           `json:"stderr_bytes"`
	StderrTruncated bool            `json:"stderr_truncated"`
	StdoutBytes     int64           `json:"stdout_bytes"`
	StdoutTruncated bool            `json:"stdout_truncated"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		Command         respjson.Field
		CreatedAt       respjson.Field
		ExecutionID     respjson.Field
		MachineID       respjson.Field
		Status          respjson.Field
		Artifacts       respjson.Field
		CompletedAt     respjson.Field
		Cwd             respjson.Field
		EnvKeys         respjson.Field
		ErrorCode       respjson.Field
		ErrorMessage    respjson.Field
		ExitCode        respjson.Field
		ExpiresAt       respjson.Field
		RetryAfterMs    respjson.Field
		Signal          respjson.Field
		StartedAt       respjson.Field
		StderrBytes     respjson.Field
		StderrTruncated respjson.Field
		StdoutBytes     respjson.Field
		StdoutTruncated respjson.Field
		ExtraFields     map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (Execution) RawJSON

func (r Execution) RawJSON() string

Returns the unmodified JSON received from the API

func (*Execution) UnmarshalJSON

func (r *Execution) UnmarshalJSON(data []byte) error

type ExecutionCreateParams

type ExecutionCreateParams struct {
	Command   []string          `json:"command,omitzero" api:"required"`
	Cwd       param.Opt[string] `json:"cwd,omitzero"`
	Stdin     param.Opt[string] `json:"stdin,omitzero"`
	TimeoutMs param.Opt[int64]  `json:"timeout_ms,omitzero"`
	Env       map[string]string `json:"env,omitzero"`
	// contains filtered or unexported fields
}

The property Command is required.

func (ExecutionCreateParams) MarshalJSON

func (r ExecutionCreateParams) MarshalJSON() (data []byte, err error)

func (*ExecutionCreateParams) UnmarshalJSON

func (r *ExecutionCreateParams) UnmarshalJSON(data []byte) error

type ExecutionEvent

type ExecutionEvent struct {
	At       time.Time `json:"at" api:"required" format:"date-time"`
	Sequence int64     `json:"sequence" api:"required"`
	// Any of "lifecycle", "stdout", "stderr".
	Type         ExecutionEventType `json:"type" api:"required"`
	Chunk        string             `json:"chunk"`
	ErrorCode    string             `json:"error_code"`
	ErrorMessage string             `json:"error_message"`
	ExitCode     int64              `json:"exit_code"`
	Signal       int64              `json:"signal"`
	// Any of "wake_in_progress", "queued", "running", "succeeded", "failed",
	// "cancelled", "expired".
	Status ExecutionEventStatus `json:"status"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		At           respjson.Field
		Sequence     respjson.Field
		Type         respjson.Field
		Chunk        respjson.Field
		ErrorCode    respjson.Field
		ErrorMessage respjson.Field
		ExitCode     respjson.Field
		Signal       respjson.Field
		Status       respjson.Field
		ExtraFields  map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (ExecutionEvent) RawJSON

func (r ExecutionEvent) RawJSON() string

Returns the unmodified JSON received from the API

func (*ExecutionEvent) UnmarshalJSON

func (r *ExecutionEvent) UnmarshalJSON(data []byte) error

type ExecutionEventStatus

type ExecutionEventStatus string
const (
	ExecutionEventStatusWakeInProgress ExecutionEventStatus = "wake_in_progress"
	ExecutionEventStatusQueued         ExecutionEventStatus = "queued"
	ExecutionEventStatusRunning        ExecutionEventStatus = "running"
	ExecutionEventStatusSucceeded      ExecutionEventStatus = "succeeded"
	ExecutionEventStatusFailed         ExecutionEventStatus = "failed"
	ExecutionEventStatusCancelled      ExecutionEventStatus = "cancelled"
	ExecutionEventStatusExpired        ExecutionEventStatus = "expired"
)

type ExecutionEventType

type ExecutionEventType string
const (
	ExecutionEventTypeLifecycle ExecutionEventType = "lifecycle"
	ExecutionEventTypeStdout    ExecutionEventType = "stdout"
	ExecutionEventTypeStderr    ExecutionEventType = "stderr"
)

type ExecutionEvents

type ExecutionEvents struct {
	Items      []ExecutionEvent `json:"items" api:"required"`
	NextCursor string           `json:"next_cursor"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		Items       respjson.Field
		NextCursor  respjson.Field
		ExtraFields map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (ExecutionEvents) RawJSON

func (r ExecutionEvents) RawJSON() string

Returns the unmodified JSON received from the API

func (*ExecutionEvents) UnmarshalJSON

func (r *ExecutionEvents) UnmarshalJSON(data []byte) error

type ExecutionList

type ExecutionList struct {
	Items      []Execution `json:"items" api:"required"`
	NextCursor string      `json:"next_cursor"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		Items       respjson.Field
		NextCursor  respjson.Field
		ExtraFields map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (ExecutionList) RawJSON

func (r ExecutionList) RawJSON() string

Returns the unmodified JSON received from the API

func (*ExecutionList) UnmarshalJSON

func (r *ExecutionList) UnmarshalJSON(data []byte) error

type ExecutionOutput

type ExecutionOutput struct {
	ExecutionID     string `json:"execution_id" api:"required"`
	Stderr          string `json:"stderr"`
	StderrBytes     int64  `json:"stderr_bytes"`
	StderrTruncated bool   `json:"stderr_truncated"`
	Stdout          string `json:"stdout"`
	StdoutBytes     int64  `json:"stdout_bytes"`
	StdoutTruncated bool   `json:"stdout_truncated"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		ExecutionID     respjson.Field
		Stderr          respjson.Field
		StderrBytes     respjson.Field
		StderrTruncated respjson.Field
		Stdout          respjson.Field
		StdoutBytes     respjson.Field
		StdoutTruncated respjson.Field
		ExtraFields     map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (ExecutionOutput) RawJSON

func (r ExecutionOutput) RawJSON() string

Returns the unmodified JSON received from the API

func (*ExecutionOutput) UnmarshalJSON

func (r *ExecutionOutput) UnmarshalJSON(data []byte) error

type ExecutionStatus

type ExecutionStatus string
const (
	ExecutionStatusWakeInProgress ExecutionStatus = "wake_in_progress"
	ExecutionStatusQueued         ExecutionStatus = "queued"
	ExecutionStatusRunning        ExecutionStatus = "running"
	ExecutionStatusSucceeded      ExecutionStatus = "succeeded"
	ExecutionStatusFailed         ExecutionStatus = "failed"
	ExecutionStatusCancelled      ExecutionStatus = "cancelled"
	ExecutionStatusExpired        ExecutionStatus = "expired"
)

type LifecycleStatus

type LifecycleStatus struct {
	LastProgressAt   time.Time `json:"last_progress_at" api:"required" format:"date-time"`
	LastTransitionAt time.Time `json:"last_transition_at" api:"required" format:"date-time"`
	// Any of "accepted", "placement_pending", "starting", "running", "stopping",
	// "sleeping", "destroying", "destroyed", "failed".
	Phase     LifecycleStatusPhase `json:"phase" api:"required"`
	Reason    string               `json:"reason" api:"required"`
	Retryable bool                 `json:"retryable" api:"required"`
	Revision  string               `json:"revision" api:"required"`
	LastError string               `json:"last_error"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		LastProgressAt   respjson.Field
		LastTransitionAt respjson.Field
		Phase            respjson.Field
		Reason           respjson.Field
		Retryable        respjson.Field
		Revision         respjson.Field
		LastError        respjson.Field
		ExtraFields      map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (LifecycleStatus) RawJSON

func (r LifecycleStatus) RawJSON() string

Returns the unmodified JSON received from the API

func (*LifecycleStatus) UnmarshalJSON

func (r *LifecycleStatus) UnmarshalJSON(data []byte) error

type LifecycleStatusPhase

type LifecycleStatusPhase string
const (
	LifecycleStatusPhaseAccepted         LifecycleStatusPhase = "accepted"
	LifecycleStatusPhasePlacementPending LifecycleStatusPhase = "placement_pending"
	LifecycleStatusPhaseStarting         LifecycleStatusPhase = "starting"
	LifecycleStatusPhaseRunning          LifecycleStatusPhase = "running"
	LifecycleStatusPhaseStopping         LifecycleStatusPhase = "stopping"
	LifecycleStatusPhaseSleeping         LifecycleStatusPhase = "sleeping"
	LifecycleStatusPhaseDestroying       LifecycleStatusPhase = "destroying"
	LifecycleStatusPhaseDestroyed        LifecycleStatusPhase = "destroyed"
	LifecycleStatusPhaseFailed           LifecycleStatusPhase = "failed"
)

type Machine added in v0.0.5

type Machine struct {
	// Seconds of inactivity before autosleep. 0 disables autosleep.
	AutosleepSeconds int64 `json:"autosleep_seconds" api:"required"`
	// Any of "running", "sleeping", "destroyed".
	DesiredState MachineDesiredState `json:"desired_state" api:"required"`
	MachineID    string              `json:"machine_id" api:"required"`
	// Memory in MiB.
	MemoryMiB int64 `json:"memory_mib" api:"required"`
	// Any of "accepted", "placement_pending", "starting", "running", "stopping",
	// "sleeping", "destroying", "destroyed", "failed".
	Phase      MachinePhase `json:"phase" api:"required"`
	StorageGiB int64        `json:"storage_gib" api:"required"`
	// CPU in vCPUs.
	VCPU float64 `json:"vcpu" api:"required"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		AutosleepSeconds respjson.Field
		DesiredState     respjson.Field
		MachineID        respjson.Field
		MemoryMiB        respjson.Field
		Phase            respjson.Field
		StorageGiB       respjson.Field
		VCPU             respjson.Field
		ExtraFields      map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (Machine) RawJSON added in v0.0.5

func (r Machine) RawJSON() string

Returns the unmodified JSON received from the API

func (*Machine) UnmarshalJSON added in v0.0.5

func (r *Machine) UnmarshalJSON(data []byte) error

type MachineDeleteParams added in v0.0.5

type MachineDeleteParams struct {
	MachineID string `path:"machine_id" api:"required" json:"-"`
	// contains filtered or unexported fields
}

type MachineDesiredState added in v0.0.5

type MachineDesiredState string
const (
	MachineDesiredStateRunning   MachineDesiredState = "running"
	MachineDesiredStateSleeping  MachineDesiredState = "sleeping"
	MachineDesiredStateDestroyed MachineDesiredState = "destroyed"
)

type MachineExecutionDeleteParams added in v0.0.5

type MachineExecutionDeleteParams struct {
	MachineID   string `path:"machine_id" api:"required" json:"-"`
	ExecutionID string `path:"execution_id" api:"required" json:"-"`
	// contains filtered or unexported fields
}

type MachineExecutionEventsParams added in v0.0.5

type MachineExecutionEventsParams struct {
	MachineID   string            `path:"machine_id" api:"required" json:"-"`
	ExecutionID string            `path:"execution_id" api:"required" json:"-"`
	Cursor      param.Opt[string] `query:"cursor,omitzero" json:"-"`
	Limit       param.Opt[int64]  `query:"limit,omitzero" json:"-"`
	// contains filtered or unexported fields
}

func (MachineExecutionEventsParams) URLQuery added in v0.0.5

func (r MachineExecutionEventsParams) URLQuery() (v url.Values, err error)

URLQuery serializes MachineExecutionEventsParams's query parameters as `url.Values`.

type MachineExecutionGetParams added in v0.0.5

type MachineExecutionGetParams struct {
	MachineID   string `path:"machine_id" api:"required" json:"-"`
	ExecutionID string `path:"execution_id" api:"required" json:"-"`
	// contains filtered or unexported fields
}

type MachineExecutionListParams added in v0.0.5

type MachineExecutionListParams struct {
	MachineID string            `path:"machine_id" api:"required" json:"-"`
	Cursor    param.Opt[string] `query:"cursor,omitzero" json:"-"`
	Limit     param.Opt[int64]  `query:"limit,omitzero" json:"-"`
	// contains filtered or unexported fields
}

func (MachineExecutionListParams) URLQuery added in v0.0.5

func (r MachineExecutionListParams) URLQuery() (v url.Values, err error)

URLQuery serializes MachineExecutionListParams's query parameters as `url.Values`.

type MachineExecutionNewParams added in v0.0.5

type MachineExecutionNewParams struct {
	MachineID             string `path:"machine_id" api:"required" json:"-"`
	ExecutionCreateParams ExecutionCreateParams
	// contains filtered or unexported fields
}

func (MachineExecutionNewParams) MarshalJSON added in v0.0.5

func (r MachineExecutionNewParams) MarshalJSON() (data []byte, err error)

func (*MachineExecutionNewParams) UnmarshalJSON added in v0.0.5

func (r *MachineExecutionNewParams) UnmarshalJSON(data []byte) error

type MachineExecutionOutputParams added in v0.0.5

type MachineExecutionOutputParams struct {
	MachineID   string `path:"machine_id" api:"required" json:"-"`
	ExecutionID string `path:"execution_id" api:"required" json:"-"`
	// contains filtered or unexported fields
}

type MachineExecutionService added in v0.0.5

type MachineExecutionService struct {
	Options []option.RequestOption
}

MachineExecutionService contains methods and other services that help with interacting with the Dedalus API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewMachineExecutionService method instead.

func NewMachineExecutionService added in v0.0.5

func NewMachineExecutionService(opts ...option.RequestOption) (r MachineExecutionService)

NewMachineExecutionService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*MachineExecutionService) Delete added in v0.0.5

Delete execution

func (*MachineExecutionService) Events added in v0.0.5

List execution events

func (*MachineExecutionService) EventsAutoPaging added in v0.0.5

List execution events

func (*MachineExecutionService) Get added in v0.0.5

Get execution

func (*MachineExecutionService) List added in v0.0.5

List executions

func (*MachineExecutionService) ListAutoPaging added in v0.0.5

List executions

func (*MachineExecutionService) New added in v0.0.5

Create execution

func (*MachineExecutionService) Output added in v0.0.5

Get execution output

type MachineGetParams added in v0.0.5

type MachineGetParams struct {
	MachineID string `path:"machine_id" api:"required" json:"-"`
	// contains filtered or unexported fields
}

type MachineGetResponse added in v0.5.0

type MachineGetResponse struct {
	// Seconds of inactivity before autosleep. 0 disables autosleep.
	AutosleepSeconds int64 `json:"autosleep_seconds" api:"required"`
	// Any of "running", "sleeping", "destroyed".
	DesiredState MachineGetResponseDesiredState `json:"desired_state" api:"required"`
	MachineID    string                         `json:"machine_id" api:"required"`
	// Memory in MiB.
	MemoryMiB  int64           `json:"memory_mib" api:"required"`
	Status     LifecycleStatus `json:"status" api:"required"`
	StorageGiB int64           `json:"storage_gib" api:"required"`
	// CPU in vCPUs.
	VCPU float64 `json:"vcpu" api:"required"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		AutosleepSeconds respjson.Field
		DesiredState     respjson.Field
		MachineID        respjson.Field
		MemoryMiB        respjson.Field
		Status           respjson.Field
		StorageGiB       respjson.Field
		VCPU             respjson.Field
		ExtraFields      map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (MachineGetResponse) RawJSON added in v0.5.0

func (r MachineGetResponse) RawJSON() string

Returns the unmodified JSON received from the API

func (*MachineGetResponse) UnmarshalJSON added in v0.5.0

func (r *MachineGetResponse) UnmarshalJSON(data []byte) error

type MachineGetResponseDesiredState added in v0.5.0

type MachineGetResponseDesiredState string
const (
	MachineGetResponseDesiredStateRunning   MachineGetResponseDesiredState = "running"
	MachineGetResponseDesiredStateSleeping  MachineGetResponseDesiredState = "sleeping"
	MachineGetResponseDesiredStateDestroyed MachineGetResponseDesiredState = "destroyed"
)

type MachineList added in v0.0.5

type MachineList struct {
	Items      []MachineListItem `json:"items" api:"required"`
	NextCursor string            `json:"next_cursor"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		Items       respjson.Field
		NextCursor  respjson.Field
		ExtraFields map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (MachineList) RawJSON added in v0.0.5

func (r MachineList) RawJSON() string

Returns the unmodified JSON received from the API

func (*MachineList) UnmarshalJSON added in v0.0.5

func (r *MachineList) UnmarshalJSON(data []byte) error

type MachineListItem added in v0.0.5

type MachineListItem struct {
	// Seconds of inactivity before autosleep. 0 disables autosleep.
	AutosleepSeconds int64     `json:"autosleep_seconds" api:"required"`
	CreatedAt        time.Time `json:"created_at" api:"required" format:"date-time"`
	// Any of "running", "sleeping", "destroyed".
	DesiredState MachineListItemDesiredState `json:"desired_state" api:"required"`
	MachineID    string                      `json:"machine_id" api:"required"`
	// Memory in MiB.
	MemoryMiB int64 `json:"memory_mib" api:"required"`
	// Any of "accepted", "placement_pending", "starting", "running", "stopping",
	// "sleeping", "destroying", "destroyed", "failed".
	Phase      MachineListItemPhase `json:"phase" api:"required"`
	StorageGiB int64                `json:"storage_gib" api:"required"`
	// CPU in vCPUs.
	VCPU float64 `json:"vcpu" api:"required"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		AutosleepSeconds respjson.Field
		CreatedAt        respjson.Field
		DesiredState     respjson.Field
		MachineID        respjson.Field
		MemoryMiB        respjson.Field
		Phase            respjson.Field
		StorageGiB       respjson.Field
		VCPU             respjson.Field
		ExtraFields      map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (MachineListItem) RawJSON added in v0.0.5

func (r MachineListItem) RawJSON() string

Returns the unmodified JSON received from the API

func (*MachineListItem) UnmarshalJSON added in v0.0.5

func (r *MachineListItem) UnmarshalJSON(data []byte) error

type MachineListItemDesiredState added in v0.0.5

type MachineListItemDesiredState string
const (
	MachineListItemDesiredStateRunning   MachineListItemDesiredState = "running"
	MachineListItemDesiredStateSleeping  MachineListItemDesiredState = "sleeping"
	MachineListItemDesiredStateDestroyed MachineListItemDesiredState = "destroyed"
)

type MachineListItemPhase added in v0.5.0

type MachineListItemPhase string
const (
	MachineListItemPhaseAccepted         MachineListItemPhase = "accepted"
	MachineListItemPhasePlacementPending MachineListItemPhase = "placement_pending"
	MachineListItemPhaseStarting         MachineListItemPhase = "starting"
	MachineListItemPhaseRunning          MachineListItemPhase = "running"
	MachineListItemPhaseStopping         MachineListItemPhase = "stopping"
	MachineListItemPhaseSleeping         MachineListItemPhase = "sleeping"
	MachineListItemPhaseDestroying       MachineListItemPhase = "destroying"
	MachineListItemPhaseDestroyed        MachineListItemPhase = "destroyed"
	MachineListItemPhaseFailed           MachineListItemPhase = "failed"
)

type MachineListParams added in v0.0.5

type MachineListParams struct {
	Cursor param.Opt[string] `query:"cursor,omitzero" json:"-"`
	Limit  param.Opt[int64]  `query:"limit,omitzero" json:"-"`
	// contains filtered or unexported fields
}

func (MachineListParams) URLQuery added in v0.0.5

func (r MachineListParams) URLQuery() (v url.Values, err error)

URLQuery serializes MachineListParams's query parameters as `url.Values`.

type MachineNewParams added in v0.0.5

type MachineNewParams struct {
	CreateParams CreateParams
	// contains filtered or unexported fields
}

func (MachineNewParams) MarshalJSON added in v0.0.5

func (r MachineNewParams) MarshalJSON() (data []byte, err error)

func (*MachineNewParams) UnmarshalJSON added in v0.0.5

func (r *MachineNewParams) UnmarshalJSON(data []byte) error

type MachinePhase added in v0.5.0

type MachinePhase string
const (
	MachinePhaseAccepted         MachinePhase = "accepted"
	MachinePhasePlacementPending MachinePhase = "placement_pending"
	MachinePhaseStarting         MachinePhase = "starting"
	MachinePhaseRunning          MachinePhase = "running"
	MachinePhaseStopping         MachinePhase = "stopping"
	MachinePhaseSleeping         MachinePhase = "sleeping"
	MachinePhaseDestroying       MachinePhase = "destroying"
	MachinePhaseDestroyed        MachinePhase = "destroyed"
	MachinePhaseFailed           MachinePhase = "failed"
)

type MachineSSHDeleteParams added in v0.0.5

type MachineSSHDeleteParams struct {
	MachineID string `path:"machine_id" api:"required" json:"-"`
	SessionID string `path:"session_id" api:"required" json:"-"`
	// contains filtered or unexported fields
}

type MachineSSHGetParams added in v0.0.5

type MachineSSHGetParams struct {
	MachineID string `path:"machine_id" api:"required" json:"-"`
	SessionID string `path:"session_id" api:"required" json:"-"`
	// contains filtered or unexported fields
}

type MachineSSHListParams added in v0.0.5

type MachineSSHListParams struct {
	MachineID string            `path:"machine_id" api:"required" json:"-"`
	Cursor    param.Opt[string] `query:"cursor,omitzero" json:"-"`
	Limit     param.Opt[int64]  `query:"limit,omitzero" json:"-"`
	// contains filtered or unexported fields
}

func (MachineSSHListParams) URLQuery added in v0.0.5

func (r MachineSSHListParams) URLQuery() (v url.Values, err error)

URLQuery serializes MachineSSHListParams's query parameters as `url.Values`.

type MachineSSHNewParams added in v0.0.5

type MachineSSHNewParams struct {
	MachineID              string `path:"machine_id" api:"required" json:"-"`
	SSHSessionCreateParams SSHSessionCreateParams
	// contains filtered or unexported fields
}

func (MachineSSHNewParams) MarshalJSON added in v0.0.5

func (r MachineSSHNewParams) MarshalJSON() (data []byte, err error)

func (*MachineSSHNewParams) UnmarshalJSON added in v0.0.5

func (r *MachineSSHNewParams) UnmarshalJSON(data []byte) error

type MachineSSHService added in v0.0.5

type MachineSSHService struct {
	Options []option.RequestOption
}

MachineSSHService contains methods and other services that help with interacting with the Dedalus API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewMachineSSHService method instead.

func NewMachineSSHService added in v0.0.5

func NewMachineSSHService(opts ...option.RequestOption) (r MachineSSHService)

NewMachineSSHService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*MachineSSHService) Delete added in v0.0.5

func (r *MachineSSHService) Delete(ctx context.Context, body MachineSSHDeleteParams, opts ...option.RequestOption) (res *SSHSession, err error)

Delete SSH session

func (*MachineSSHService) Get added in v0.0.5

func (r *MachineSSHService) Get(ctx context.Context, query MachineSSHGetParams, opts ...option.RequestOption) (res *SSHSession, err error)

Get SSH session

func (*MachineSSHService) List added in v0.0.5

List SSH sessions

func (*MachineSSHService) ListAutoPaging added in v0.0.5

List SSH sessions

func (*MachineSSHService) New added in v0.0.5

func (r *MachineSSHService) New(ctx context.Context, params MachineSSHNewParams, opts ...option.RequestOption) (res *SSHSession, err error)

Create SSH session

type MachineService added in v0.0.5

type MachineService struct {
	Options    []option.RequestOption
	SSH        MachineSSHService
	Executions MachineExecutionService
}

MachineService contains methods and other services that help with interacting with the Dedalus API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewMachineService method instead.

func NewMachineService added in v0.0.5

func NewMachineService(opts ...option.RequestOption) (r MachineService)

NewMachineService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*MachineService) Delete added in v0.0.5

func (r *MachineService) Delete(ctx context.Context, body MachineDeleteParams, opts ...option.RequestOption) (res *Machine, err error)

Destroy machine

func (*MachineService) Get added in v0.0.5

Get machine

func (*MachineService) List added in v0.0.5

List machines

func (*MachineService) ListAutoPaging added in v0.0.5

List machines

func (*MachineService) New added in v0.0.5

func (r *MachineService) New(ctx context.Context, body MachineNewParams, opts ...option.RequestOption) (res *Machine, err error)

Create machine

func (*MachineService) Sleep added in v0.1.0

func (r *MachineService) Sleep(ctx context.Context, body MachineSleepParams, opts ...option.RequestOption) (res *Machine, err error)

Sleep a running machine

func (*MachineService) Update added in v0.0.5

func (r *MachineService) Update(ctx context.Context, params MachineUpdateParams, opts ...option.RequestOption) (res *Machine, err error)

Update machine

func (*MachineService) Wake added in v0.1.0

func (r *MachineService) Wake(ctx context.Context, body MachineWakeParams, opts ...option.RequestOption) (res *Machine, err error)

Wake a sleeping machine

type MachineSleepParams added in v0.1.0

type MachineSleepParams struct {
	MachineID string `path:"machine_id" api:"required" json:"-"`
	// contains filtered or unexported fields
}

type MachineUpdateParams added in v0.0.5

type MachineUpdateParams struct {
	MachineID    string `path:"machine_id" api:"required" json:"-"`
	UpdateParams UpdateParams
	// contains filtered or unexported fields
}

func (MachineUpdateParams) MarshalJSON added in v0.0.5

func (r MachineUpdateParams) MarshalJSON() (data []byte, err error)

func (*MachineUpdateParams) UnmarshalJSON added in v0.0.5

func (r *MachineUpdateParams) UnmarshalJSON(data []byte) error

type MachineWakeParams added in v0.1.0

type MachineWakeParams struct {
	MachineID string `path:"machine_id" api:"required" json:"-"`
	// contains filtered or unexported fields
}

type SSHConnection

type SSHConnection struct {
	Endpoint        string       `json:"endpoint" api:"required"`
	Port            int64        `json:"port" api:"required"`
	SSHUsername     string       `json:"ssh_username" api:"required"`
	HostTrust       SSHHostTrust `json:"host_trust"`
	UserCertificate string       `json:"user_certificate"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		Endpoint        respjson.Field
		Port            respjson.Field
		SSHUsername     respjson.Field
		HostTrust       respjson.Field
		UserCertificate respjson.Field
		ExtraFields     map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (SSHConnection) RawJSON

func (r SSHConnection) RawJSON() string

Returns the unmodified JSON received from the API

func (*SSHConnection) UnmarshalJSON

func (r *SSHConnection) UnmarshalJSON(data []byte) error

type SSHHostTrust

type SSHHostTrust struct {
	HostPattern string `json:"host_pattern" api:"required"`
	// Any of "cert_authority".
	Kind      SSHHostTrustKind `json:"kind" api:"required"`
	PublicKey string           `json:"public_key" api:"required"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		HostPattern respjson.Field
		Kind        respjson.Field
		PublicKey   respjson.Field
		ExtraFields map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (SSHHostTrust) RawJSON

func (r SSHHostTrust) RawJSON() string

Returns the unmodified JSON received from the API

func (*SSHHostTrust) UnmarshalJSON

func (r *SSHHostTrust) UnmarshalJSON(data []byte) error

type SSHHostTrustKind

type SSHHostTrustKind string
const (
	SSHHostTrustKindCertAuthority SSHHostTrustKind = "cert_authority"
)

type SSHSession

type SSHSession struct {
	CreatedAt time.Time `json:"created_at" api:"required" format:"date-time"`
	MachineID string    `json:"machine_id" api:"required"`
	SessionID string    `json:"session_id" api:"required"`
	// Any of "wake_in_progress", "ready", "closed", "expired", "failed".
	Status       SSHSessionStatus `json:"status" api:"required"`
	Connection   SSHConnection    `json:"connection"`
	ErrorCode    string           `json:"error_code"`
	ErrorMessage string           `json:"error_message"`
	ExpiresAt    time.Time        `json:"expires_at" format:"date-time"`
	ReadyAt      time.Time        `json:"ready_at" format:"date-time"`
	RetryAfterMs int64            `json:"retry_after_ms"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		CreatedAt    respjson.Field
		MachineID    respjson.Field
		SessionID    respjson.Field
		Status       respjson.Field
		Connection   respjson.Field
		ErrorCode    respjson.Field
		ErrorMessage respjson.Field
		ExpiresAt    respjson.Field
		ReadyAt      respjson.Field
		RetryAfterMs respjson.Field
		ExtraFields  map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (SSHSession) RawJSON

func (r SSHSession) RawJSON() string

Returns the unmodified JSON received from the API

func (*SSHSession) UnmarshalJSON

func (r *SSHSession) UnmarshalJSON(data []byte) error

type SSHSessionCreateParams

type SSHSessionCreateParams struct {
	PublicKey string `json:"public_key" api:"required"`
	// contains filtered or unexported fields
}

The property PublicKey is required.

func (SSHSessionCreateParams) MarshalJSON

func (r SSHSessionCreateParams) MarshalJSON() (data []byte, err error)

func (*SSHSessionCreateParams) UnmarshalJSON

func (r *SSHSessionCreateParams) UnmarshalJSON(data []byte) error

type SSHSessionList

type SSHSessionList struct {
	Items      []SSHSession `json:"items" api:"required"`
	NextCursor string       `json:"next_cursor"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		Items       respjson.Field
		NextCursor  respjson.Field
		ExtraFields map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (SSHSessionList) RawJSON

func (r SSHSessionList) RawJSON() string

Returns the unmodified JSON received from the API

func (*SSHSessionList) UnmarshalJSON

func (r *SSHSessionList) UnmarshalJSON(data []byte) error

type SSHSessionStatus

type SSHSessionStatus string
const (
	SSHSessionStatusWakeInProgress SSHSessionStatus = "wake_in_progress"
	SSHSessionStatusReady          SSHSessionStatus = "ready"
	SSHSessionStatusClosed         SSHSessionStatus = "closed"
	SSHSessionStatusExpired        SSHSessionStatus = "expired"
	SSHSessionStatusFailed         SSHSessionStatus = "failed"
)

type UpdateParams

type UpdateParams struct {
	// Idle window before autosleep. Accepts fixed duration units like 30s, 30m, 2h,
	// 7d3h4s, or 1w3d, raw seconds ("1800"), or never to disable.
	Autosleep param.Opt[string] `json:"autosleep,omitzero"`
	// Memory in MiB.
	MemoryMiB param.Opt[int64] `json:"memory_mib,omitzero"`
	// Storage in GiB.
	StorageGiB param.Opt[int64] `json:"storage_gib,omitzero"`
	// CPU in vCPUs.
	VCPU param.Opt[float64] `json:"vcpu,omitzero"`
	// contains filtered or unexported fields
}

func (UpdateParams) MarshalJSON

func (r UpdateParams) MarshalJSON() (data []byte, err error)

func (*UpdateParams) UnmarshalJSON

func (r *UpdateParams) UnmarshalJSON(data []byte) error

Directories

Path Synopsis
encoding/json
Package json implements encoding and decoding of JSON as defined in RFC 7159.
Package json implements encoding and decoding of JSON as defined in RFC 7159.
encoding/json/shims
This package provides shims over Go 1.2{2,3} APIs which are missing from Go 1.22, and used by the Go 1.24 encoding/json package.
This package provides shims over Go 1.2{2,3} APIs which are missing from Go 1.22, and used by the Go 1.24 encoding/json package.
packages
shared

Jump to