Documentation
¶
Index ¶
- func Bool(b bool) param.Opt[bool]
- func BoolPtr(v bool) *bool
- func DefaultClientOptions() []option.RequestOption
- func File(rdr io.Reader, filename string, contentType string) file
- func Float(f float64) param.Opt[float64]
- func FloatPtr(v float64) *float64
- func Int(i int64) param.Opt[int64]
- func IntPtr(v int64) *int64
- func Opt[T comparable](v T) param.Opt[T]
- func Ptr[T any](v T) *T
- func String(s string) param.Opt[string]
- func StringPtr(v string) *string
- func Time(t time.Time) param.Opt[time.Time]
- func TimePtr(v time.Time) *time.Time
- type Artifact
- type ArtifactList
- type ArtifactRef
- type Client
- func (r *Client) Delete(ctx context.Context, path string, params any, res any, ...) error
- func (r *Client) Execute(ctx context.Context, method string, path string, params any, res any, ...) error
- func (r *Client) Get(ctx context.Context, path string, params any, res any, ...) error
- func (r *Client) Patch(ctx context.Context, path string, params any, res any, ...) error
- func (r *Client) Post(ctx context.Context, path string, params any, res any, ...) error
- func (r *Client) Put(ctx context.Context, path string, params any, res any, ...) error
- type CreateParams
- type Error
- type Execution
- type ExecutionCreateParams
- type ExecutionEvent
- type ExecutionEventStatus
- type ExecutionEventType
- type ExecutionEvents
- type ExecutionList
- type ExecutionOutput
- type ExecutionStatus
- type LifecycleStatus
- type LifecycleStatusPhase
- type Preview
- type PreviewCreateParams
- type PreviewCreateParamsProtocol
- type PreviewList
- type PreviewProtocol
- type PreviewStatus
- type SSHConnection
- type SSHHostTrust
- type SSHHostTrustKind
- type SSHSession
- type SSHSessionCreateParams
- type SSHSessionList
- type SSHSessionStatus
- type Terminal
- type TerminalCreateParams
- type TerminalList
- type TerminalProtocol
- type TerminalStatus
- type UpdateParams
- type Workspace
- type WorkspaceArtifactDeleteParams
- type WorkspaceArtifactGetParams
- type WorkspaceArtifactListParams
- type WorkspaceArtifactService
- func (r *WorkspaceArtifactService) Delete(ctx context.Context, artifactID string, body WorkspaceArtifactDeleteParams, ...) (res *Artifact, err error)
- func (r *WorkspaceArtifactService) Get(ctx context.Context, artifactID string, query WorkspaceArtifactGetParams, ...) (res *Artifact, err error)
- func (r *WorkspaceArtifactService) List(ctx context.Context, workspaceID string, query WorkspaceArtifactListParams, ...) (res *pagination.CursorPage[Artifact], err error)
- func (r *WorkspaceArtifactService) ListAutoPaging(ctx context.Context, workspaceID string, query WorkspaceArtifactListParams, ...) *pagination.CursorPageAutoPager[Artifact]
- type WorkspaceDeleteParams
- type WorkspaceDesiredState
- type WorkspaceExecutionDeleteParams
- type WorkspaceExecutionEventsParams
- type WorkspaceExecutionGetParams
- type WorkspaceExecutionListParams
- type WorkspaceExecutionNewParams
- type WorkspaceExecutionOutputParams
- type WorkspaceExecutionService
- func (r *WorkspaceExecutionService) Delete(ctx context.Context, executionID string, body WorkspaceExecutionDeleteParams, ...) (res *Execution, err error)
- func (r *WorkspaceExecutionService) Events(ctx context.Context, executionID string, params WorkspaceExecutionEventsParams, ...) (res *pagination.CursorPage[ExecutionEvent], err error)
- func (r *WorkspaceExecutionService) EventsAutoPaging(ctx context.Context, executionID string, params WorkspaceExecutionEventsParams, ...) *pagination.CursorPageAutoPager[ExecutionEvent]
- func (r *WorkspaceExecutionService) Get(ctx context.Context, executionID string, query WorkspaceExecutionGetParams, ...) (res *Execution, err error)
- func (r *WorkspaceExecutionService) List(ctx context.Context, workspaceID string, query WorkspaceExecutionListParams, ...) (res *pagination.CursorPage[Execution], err error)
- func (r *WorkspaceExecutionService) ListAutoPaging(ctx context.Context, workspaceID string, query WorkspaceExecutionListParams, ...) *pagination.CursorPageAutoPager[Execution]
- func (r *WorkspaceExecutionService) New(ctx context.Context, workspaceID string, body WorkspaceExecutionNewParams, ...) (res *Execution, err error)
- func (r *WorkspaceExecutionService) Output(ctx context.Context, executionID string, query WorkspaceExecutionOutputParams, ...) (res *ExecutionOutput, err error)
- type WorkspaceList
- type WorkspaceListItem
- type WorkspaceListParams
- type WorkspaceNewParams
- type WorkspacePreviewDeleteParams
- type WorkspacePreviewGetParams
- type WorkspacePreviewListParams
- type WorkspacePreviewNewParams
- type WorkspacePreviewService
- func (r *WorkspacePreviewService) Delete(ctx context.Context, previewID string, body WorkspacePreviewDeleteParams, ...) (res *Preview, err error)
- func (r *WorkspacePreviewService) Get(ctx context.Context, previewID string, query WorkspacePreviewGetParams, ...) (res *Preview, err error)
- func (r *WorkspacePreviewService) List(ctx context.Context, workspaceID string, query WorkspacePreviewListParams, ...) (res *pagination.CursorPage[Preview], err error)
- func (r *WorkspacePreviewService) ListAutoPaging(ctx context.Context, workspaceID string, query WorkspacePreviewListParams, ...) *pagination.CursorPageAutoPager[Preview]
- func (r *WorkspacePreviewService) New(ctx context.Context, workspaceID string, body WorkspacePreviewNewParams, ...) (res *Preview, err error)
- type WorkspaceSSHDeleteParams
- type WorkspaceSSHGetParams
- type WorkspaceSSHListParams
- type WorkspaceSSHNewParams
- type WorkspaceSSHService
- func (r *WorkspaceSSHService) Delete(ctx context.Context, sessionID string, body WorkspaceSSHDeleteParams, ...) (res *SSHSession, err error)
- func (r *WorkspaceSSHService) Get(ctx context.Context, sessionID string, query WorkspaceSSHGetParams, ...) (res *SSHSession, err error)
- func (r *WorkspaceSSHService) List(ctx context.Context, workspaceID string, query WorkspaceSSHListParams, ...) (res *pagination.CursorPage[SSHSession], err error)
- func (r *WorkspaceSSHService) ListAutoPaging(ctx context.Context, workspaceID string, query WorkspaceSSHListParams, ...) *pagination.CursorPageAutoPager[SSHSession]
- func (r *WorkspaceSSHService) New(ctx context.Context, workspaceID string, body WorkspaceSSHNewParams, ...) (res *SSHSession, err error)
- type WorkspaceService
- func (r *WorkspaceService) Delete(ctx context.Context, workspaceID string, body WorkspaceDeleteParams, ...) (res *Workspace, err error)
- func (r *WorkspaceService) Get(ctx context.Context, workspaceID string, opts ...option.RequestOption) (res *Workspace, err error)
- func (r *WorkspaceService) List(ctx context.Context, query WorkspaceListParams, opts ...option.RequestOption) (res *pagination.CursorPage[WorkspaceListItem], err error)
- func (r *WorkspaceService) ListAutoPaging(ctx context.Context, query WorkspaceListParams, opts ...option.RequestOption) *pagination.CursorPageAutoPager[WorkspaceListItem]
- func (r *WorkspaceService) New(ctx context.Context, body WorkspaceNewParams, opts ...option.RequestOption) (res *Workspace, err error)
- func (r *WorkspaceService) Update(ctx context.Context, workspaceID string, params WorkspaceUpdateParams, ...) (res *Workspace, err error)
- type WorkspaceTerminalDeleteParams
- type WorkspaceTerminalGetParams
- type WorkspaceTerminalListParams
- type WorkspaceTerminalNewParams
- type WorkspaceTerminalService
- func (r *WorkspaceTerminalService) Delete(ctx context.Context, terminalID string, body WorkspaceTerminalDeleteParams, ...) (res *Terminal, err error)
- func (r *WorkspaceTerminalService) Get(ctx context.Context, terminalID string, query WorkspaceTerminalGetParams, ...) (res *Terminal, err error)
- func (r *WorkspaceTerminalService) List(ctx context.Context, workspaceID string, query WorkspaceTerminalListParams, ...) (res *pagination.CursorPage[Terminal], err error)
- func (r *WorkspaceTerminalService) ListAutoPaging(ctx context.Context, workspaceID string, query WorkspaceTerminalListParams, ...) *pagination.CursorPageAutoPager[Terminal]
- func (r *WorkspaceTerminalService) New(ctx context.Context, workspaceID string, body WorkspaceTerminalNewParams, ...) (res *Terminal, err error)
- type WorkspaceUpdateParams
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultClientOptions ¶
func DefaultClientOptions() []option.RequestOption
DefaultClientOptions read from the environment (DEDALUS_API_KEY, DEDALUS_X_API_KEY, DEDALUS_ORG_ID, DEDALUS_BASE_URL). This should be used to initialize new clients.
func Opt ¶
func Opt[T comparable](v T) param.Opt[T]
Types ¶
type Artifact ¶
type Artifact struct {
ArtifactID string `json:"artifact_id" api:"required"`
CreatedAt time.Time `json:"created_at" api:"required" format:"date-time"`
Name string `json:"name" api:"required"`
SizeBytes int64 `json:"size_bytes" api:"required"`
WorkspaceID string `json:"workspace_id" api:"required"`
DownloadURL string `json:"download_url"`
ExecutionID string `json:"execution_id"`
ExpiresAt time.Time `json:"expires_at" format:"date-time"`
MimeType string `json:"mime_type"`
Sha256 string `json:"sha256"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
ArtifactID respjson.Field
CreatedAt respjson.Field
Name respjson.Field
SizeBytes respjson.Field
WorkspaceID respjson.Field
DownloadURL respjson.Field
ExecutionID respjson.Field
ExpiresAt respjson.Field
MimeType respjson.Field
Sha256 respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (*Artifact) UnmarshalJSON ¶
type ArtifactList ¶
type ArtifactList struct {
Items []Artifact `json:"items" api:"required"`
NextCursor string `json:"next_cursor"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
Items respjson.Field
NextCursor respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (ArtifactList) RawJSON ¶
func (r ArtifactList) RawJSON() string
Returns the unmodified JSON received from the API
func (*ArtifactList) UnmarshalJSON ¶
func (r *ArtifactList) UnmarshalJSON(data []byte) error
type ArtifactRef ¶
type ArtifactRef struct {
ArtifactID string `json:"artifact_id" api:"required"`
Name string `json:"name" api:"required"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
ArtifactID respjson.Field
Name respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (ArtifactRef) RawJSON ¶
func (r ArtifactRef) RawJSON() string
Returns the unmodified JSON received from the API
func (*ArtifactRef) UnmarshalJSON ¶
func (r *ArtifactRef) UnmarshalJSON(data []byte) error
type Client ¶
type Client struct {
Options []option.RequestOption
Workspaces WorkspaceService
}
Client creates a struct with services and top level methods that help with interacting with the Dedalus API. You should not instantiate this client directly, and instead use the NewClient method instead.
func NewClient ¶
func NewClient(opts ...option.RequestOption) (r Client)
NewClient generates a new client with the default option read from the environment (DEDALUS_API_KEY, DEDALUS_X_API_KEY, DEDALUS_ORG_ID, DEDALUS_BASE_URL). The option passed in as arguments are applied after these default arguments, and all option will be passed down to the services and requests that this client makes.
func (*Client) Delete ¶
func (r *Client) Delete(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error
Delete makes a DELETE request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.
func (*Client) Execute ¶
func (r *Client) Execute(ctx context.Context, method string, path string, params any, res any, opts ...option.RequestOption) error
Execute makes a request with the given context, method, URL, request params, response, and request options. This is useful for hitting undocumented endpoints while retaining the base URL, auth, retries, and other options from the client.
If a byte slice or an io.Reader is supplied to params, it will be used as-is for the request body.
The params is by default serialized into the body using encoding/json. If your type implements a MarshalJSON function, it will be used instead to serialize the request. If a URLQuery method is implemented, the returned url.Values will be used as query strings to the url.
If your params struct uses param.Field, you must provide either [MarshalJSON], [URLQuery], and/or [MarshalForm] functions. It is undefined behavior to use a struct uses param.Field without specifying how it is serialized.
Any "…Params" object defined in this library can be used as the request argument. Note that 'path' arguments will not be forwarded into the url.
The response body will be deserialized into the res variable, depending on its type:
- A pointer to a *http.Response is populated by the raw response.
- A pointer to a byte array will be populated with the contents of the request body.
- A pointer to any other type uses this library's default JSON decoding, which respects UnmarshalJSON if it is defined on the type.
- A nil value will not read the response body.
For even greater flexibility, see option.WithResponseInto and option.WithResponseBodyInto.
func (*Client) Get ¶
func (r *Client) Get(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error
Get makes a GET request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.
func (*Client) Patch ¶
func (r *Client) Patch(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error
Patch makes a PATCH request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.
type CreateParams ¶
type CreateParams struct {
// Memory in MiB.
MemoryMiB int64 `json:"memory_mib" api:"required"`
StorageGiB int64 `json:"storage_gib" api:"required"`
// CPU in vCPUs.
VCPU float64 `json:"vcpu" api:"required"`
// contains filtered or unexported fields
}
The properties MemoryMiB, StorageGiB, VCPU are required.
func (CreateParams) MarshalJSON ¶
func (r CreateParams) MarshalJSON() (data []byte, err error)
func (*CreateParams) UnmarshalJSON ¶
func (r *CreateParams) UnmarshalJSON(data []byte) error
type Execution ¶
type Execution struct {
Command []string `json:"command" api:"required"`
CreatedAt time.Time `json:"created_at" api:"required" format:"date-time"`
ExecutionID string `json:"execution_id" api:"required"`
// Any of "wake_in_progress", "queued", "running", "succeeded", "failed",
// "cancelled", "expired".
Status ExecutionStatus `json:"status" api:"required"`
WorkspaceID string `json:"workspace_id" api:"required"`
Artifacts []ArtifactRef `json:"artifacts" api:"nullable"`
CompletedAt time.Time `json:"completed_at" format:"date-time"`
Cwd string `json:"cwd"`
EnvKeys []string `json:"env_keys" api:"nullable"`
ErrorCode string `json:"error_code"`
ErrorMessage string `json:"error_message"`
ExitCode int64 `json:"exit_code"`
ExpiresAt time.Time `json:"expires_at" format:"date-time"`
RetryAfterMs int64 `json:"retry_after_ms"`
Signal int64 `json:"signal"`
StartedAt time.Time `json:"started_at" format:"date-time"`
StderrBytes int64 `json:"stderr_bytes"`
StderrTruncated bool `json:"stderr_truncated"`
StdoutBytes int64 `json:"stdout_bytes"`
StdoutTruncated bool `json:"stdout_truncated"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
Command respjson.Field
CreatedAt respjson.Field
ExecutionID respjson.Field
Status respjson.Field
WorkspaceID respjson.Field
Artifacts respjson.Field
CompletedAt respjson.Field
Cwd respjson.Field
EnvKeys respjson.Field
ErrorCode respjson.Field
ErrorMessage respjson.Field
ExitCode respjson.Field
ExpiresAt respjson.Field
RetryAfterMs respjson.Field
Signal respjson.Field
StartedAt respjson.Field
StderrBytes respjson.Field
StderrTruncated respjson.Field
StdoutBytes respjson.Field
StdoutTruncated respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (*Execution) UnmarshalJSON ¶
type ExecutionCreateParams ¶
type ExecutionCreateParams struct {
Command []string `json:"command,omitzero" api:"required"`
Cwd param.Opt[string] `json:"cwd,omitzero"`
Stdin param.Opt[string] `json:"stdin,omitzero"`
TimeoutMs param.Opt[int64] `json:"timeout_ms,omitzero"`
WakeIfNeeded param.Opt[bool] `json:"wake_if_needed,omitzero"`
Env map[string]string `json:"env,omitzero"`
// contains filtered or unexported fields
}
The property Command is required.
func (ExecutionCreateParams) MarshalJSON ¶
func (r ExecutionCreateParams) MarshalJSON() (data []byte, err error)
func (*ExecutionCreateParams) UnmarshalJSON ¶
func (r *ExecutionCreateParams) UnmarshalJSON(data []byte) error
type ExecutionEvent ¶
type ExecutionEvent struct {
At time.Time `json:"at" api:"required" format:"date-time"`
Sequence int64 `json:"sequence" api:"required"`
// Any of "lifecycle", "stdout", "stderr".
Type ExecutionEventType `json:"type" api:"required"`
Chunk string `json:"chunk"`
ErrorCode string `json:"error_code"`
ErrorMessage string `json:"error_message"`
ExitCode int64 `json:"exit_code"`
Signal int64 `json:"signal"`
// Any of "wake_in_progress", "queued", "running", "succeeded", "failed",
// "cancelled", "expired".
Status ExecutionEventStatus `json:"status"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
At respjson.Field
Sequence respjson.Field
Type respjson.Field
Chunk respjson.Field
ErrorCode respjson.Field
ErrorMessage respjson.Field
ExitCode respjson.Field
Signal respjson.Field
Status respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (ExecutionEvent) RawJSON ¶
func (r ExecutionEvent) RawJSON() string
Returns the unmodified JSON received from the API
func (*ExecutionEvent) UnmarshalJSON ¶
func (r *ExecutionEvent) UnmarshalJSON(data []byte) error
type ExecutionEventStatus ¶
type ExecutionEventStatus string
const ( ExecutionEventStatusWakeInProgress ExecutionEventStatus = "wake_in_progress" ExecutionEventStatusQueued ExecutionEventStatus = "queued" ExecutionEventStatusRunning ExecutionEventStatus = "running" ExecutionEventStatusSucceeded ExecutionEventStatus = "succeeded" ExecutionEventStatusFailed ExecutionEventStatus = "failed" ExecutionEventStatusCancelled ExecutionEventStatus = "cancelled" ExecutionEventStatusExpired ExecutionEventStatus = "expired" )
type ExecutionEventType ¶
type ExecutionEventType string
const ( ExecutionEventTypeLifecycle ExecutionEventType = "lifecycle" ExecutionEventTypeStdout ExecutionEventType = "stdout" ExecutionEventTypeStderr ExecutionEventType = "stderr" )
type ExecutionEvents ¶
type ExecutionEvents struct {
Items []ExecutionEvent `json:"items" api:"required"`
NextCursor string `json:"next_cursor"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
Items respjson.Field
NextCursor respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (ExecutionEvents) RawJSON ¶
func (r ExecutionEvents) RawJSON() string
Returns the unmodified JSON received from the API
func (*ExecutionEvents) UnmarshalJSON ¶
func (r *ExecutionEvents) UnmarshalJSON(data []byte) error
type ExecutionList ¶
type ExecutionList struct {
Items []Execution `json:"items" api:"required"`
NextCursor string `json:"next_cursor"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
Items respjson.Field
NextCursor respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (ExecutionList) RawJSON ¶
func (r ExecutionList) RawJSON() string
Returns the unmodified JSON received from the API
func (*ExecutionList) UnmarshalJSON ¶
func (r *ExecutionList) UnmarshalJSON(data []byte) error
type ExecutionOutput ¶
type ExecutionOutput struct {
ExecutionID string `json:"execution_id" api:"required"`
Stderr string `json:"stderr"`
StderrBytes int64 `json:"stderr_bytes"`
StderrTruncated bool `json:"stderr_truncated"`
Stdout string `json:"stdout"`
StdoutBytes int64 `json:"stdout_bytes"`
StdoutTruncated bool `json:"stdout_truncated"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
ExecutionID respjson.Field
Stderr respjson.Field
StderrBytes respjson.Field
StderrTruncated respjson.Field
Stdout respjson.Field
StdoutBytes respjson.Field
StdoutTruncated respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (ExecutionOutput) RawJSON ¶
func (r ExecutionOutput) RawJSON() string
Returns the unmodified JSON received from the API
func (*ExecutionOutput) UnmarshalJSON ¶
func (r *ExecutionOutput) UnmarshalJSON(data []byte) error
type ExecutionStatus ¶
type ExecutionStatus string
const ( ExecutionStatusWakeInProgress ExecutionStatus = "wake_in_progress" ExecutionStatusQueued ExecutionStatus = "queued" ExecutionStatusRunning ExecutionStatus = "running" ExecutionStatusSucceeded ExecutionStatus = "succeeded" ExecutionStatusFailed ExecutionStatus = "failed" ExecutionStatusCancelled ExecutionStatus = "cancelled" ExecutionStatusExpired ExecutionStatus = "expired" )
type LifecycleStatus ¶
type LifecycleStatus struct {
LastProgressAt time.Time `json:"last_progress_at" api:"required" format:"date-time"`
LastTransitionAt time.Time `json:"last_transition_at" api:"required" format:"date-time"`
// Any of "accepted", "placement_pending", "starting", "running", "stopping",
// "sleeping", "destroying", "destroyed", "failed".
Phase LifecycleStatusPhase `json:"phase" api:"required"`
Reason string `json:"reason" api:"required"`
Retryable bool `json:"retryable" api:"required"`
Revision string `json:"revision" api:"required"`
LastError string `json:"last_error"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
LastProgressAt respjson.Field
LastTransitionAt respjson.Field
Phase respjson.Field
Reason respjson.Field
Retryable respjson.Field
Revision respjson.Field
LastError respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (LifecycleStatus) RawJSON ¶
func (r LifecycleStatus) RawJSON() string
Returns the unmodified JSON received from the API
func (*LifecycleStatus) UnmarshalJSON ¶
func (r *LifecycleStatus) UnmarshalJSON(data []byte) error
type LifecycleStatusPhase ¶
type LifecycleStatusPhase string
const ( LifecycleStatusPhaseAccepted LifecycleStatusPhase = "accepted" LifecycleStatusPhasePlacementPending LifecycleStatusPhase = "placement_pending" LifecycleStatusPhaseStarting LifecycleStatusPhase = "starting" LifecycleStatusPhaseRunning LifecycleStatusPhase = "running" LifecycleStatusPhaseStopping LifecycleStatusPhase = "stopping" LifecycleStatusPhaseSleeping LifecycleStatusPhase = "sleeping" LifecycleStatusPhaseDestroying LifecycleStatusPhase = "destroying" LifecycleStatusPhaseDestroyed LifecycleStatusPhase = "destroyed" LifecycleStatusPhaseFailed LifecycleStatusPhase = "failed" )
type Preview ¶
type Preview struct {
CreatedAt time.Time `json:"created_at" api:"required" format:"date-time"`
Port int64 `json:"port" api:"required"`
PreviewID string `json:"preview_id" api:"required"`
// Any of "wake_in_progress", "ready", "closed", "expired", "failed".
Status PreviewStatus `json:"status" api:"required"`
WorkspaceID string `json:"workspace_id" api:"required"`
ErrorCode string `json:"error_code"`
ErrorMessage string `json:"error_message"`
ExpiresAt time.Time `json:"expires_at" format:"date-time"`
// Any of "http", "https".
Protocol PreviewProtocol `json:"protocol"`
ReadyAt time.Time `json:"ready_at" format:"date-time"`
RetryAfterMs int64 `json:"retry_after_ms"`
URL string `json:"url"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
CreatedAt respjson.Field
Port respjson.Field
PreviewID respjson.Field
Status respjson.Field
WorkspaceID respjson.Field
ErrorCode respjson.Field
ErrorMessage respjson.Field
ExpiresAt respjson.Field
Protocol respjson.Field
ReadyAt respjson.Field
RetryAfterMs respjson.Field
URL respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (*Preview) UnmarshalJSON ¶
type PreviewCreateParams ¶
type PreviewCreateParams struct {
Port int64 `json:"port" api:"required"`
WakeIfNeeded param.Opt[bool] `json:"wake_if_needed,omitzero"`
// Any of "http", "https".
Protocol PreviewCreateParamsProtocol `json:"protocol,omitzero"`
// contains filtered or unexported fields
}
The property Port is required.
func (PreviewCreateParams) MarshalJSON ¶
func (r PreviewCreateParams) MarshalJSON() (data []byte, err error)
func (*PreviewCreateParams) UnmarshalJSON ¶
func (r *PreviewCreateParams) UnmarshalJSON(data []byte) error
type PreviewCreateParamsProtocol ¶
type PreviewCreateParamsProtocol string
const ( PreviewCreateParamsProtocolHTTP PreviewCreateParamsProtocol = "http" PreviewCreateParamsProtocolHTTPS PreviewCreateParamsProtocol = "https" )
type PreviewList ¶
type PreviewList struct {
Items []Preview `json:"items" api:"required"`
NextCursor string `json:"next_cursor"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
Items respjson.Field
NextCursor respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (PreviewList) RawJSON ¶
func (r PreviewList) RawJSON() string
Returns the unmodified JSON received from the API
func (*PreviewList) UnmarshalJSON ¶
func (r *PreviewList) UnmarshalJSON(data []byte) error
type PreviewProtocol ¶
type PreviewProtocol string
const ( PreviewProtocolHTTP PreviewProtocol = "http" PreviewProtocolHTTPS PreviewProtocol = "https" )
type PreviewStatus ¶
type PreviewStatus string
const ( PreviewStatusWakeInProgress PreviewStatus = "wake_in_progress" PreviewStatusReady PreviewStatus = "ready" PreviewStatusClosed PreviewStatus = "closed" PreviewStatusExpired PreviewStatus = "expired" PreviewStatusFailed PreviewStatus = "failed" )
type SSHConnection ¶
type SSHConnection struct {
Endpoint string `json:"endpoint" api:"required"`
Port int64 `json:"port" api:"required"`
SSHUsername string `json:"ssh_username" api:"required"`
HostTrust SSHHostTrust `json:"host_trust"`
UserCertificate string `json:"user_certificate"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
Endpoint respjson.Field
Port respjson.Field
SSHUsername respjson.Field
HostTrust respjson.Field
UserCertificate respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (SSHConnection) RawJSON ¶
func (r SSHConnection) RawJSON() string
Returns the unmodified JSON received from the API
func (*SSHConnection) UnmarshalJSON ¶
func (r *SSHConnection) UnmarshalJSON(data []byte) error
type SSHHostTrust ¶
type SSHHostTrust struct {
HostPattern string `json:"host_pattern" api:"required"`
// Any of "cert_authority".
Kind SSHHostTrustKind `json:"kind" api:"required"`
PublicKey string `json:"public_key" api:"required"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
HostPattern respjson.Field
Kind respjson.Field
PublicKey respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (SSHHostTrust) RawJSON ¶
func (r SSHHostTrust) RawJSON() string
Returns the unmodified JSON received from the API
func (*SSHHostTrust) UnmarshalJSON ¶
func (r *SSHHostTrust) UnmarshalJSON(data []byte) error
type SSHHostTrustKind ¶
type SSHHostTrustKind string
const (
SSHHostTrustKindCertAuthority SSHHostTrustKind = "cert_authority"
)
type SSHSession ¶
type SSHSession struct {
CreatedAt time.Time `json:"created_at" api:"required" format:"date-time"`
SessionID string `json:"session_id" api:"required"`
// Any of "wake_in_progress", "ready", "closed", "expired", "failed".
Status SSHSessionStatus `json:"status" api:"required"`
WorkspaceID string `json:"workspace_id" api:"required"`
Connection SSHConnection `json:"connection"`
ErrorCode string `json:"error_code"`
ErrorMessage string `json:"error_message"`
ExpiresAt time.Time `json:"expires_at" format:"date-time"`
ReadyAt time.Time `json:"ready_at" format:"date-time"`
RetryAfterMs int64 `json:"retry_after_ms"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
CreatedAt respjson.Field
SessionID respjson.Field
Status respjson.Field
WorkspaceID respjson.Field
Connection respjson.Field
ErrorCode respjson.Field
ErrorMessage respjson.Field
ExpiresAt respjson.Field
ReadyAt respjson.Field
RetryAfterMs respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (SSHSession) RawJSON ¶
func (r SSHSession) RawJSON() string
Returns the unmodified JSON received from the API
func (*SSHSession) UnmarshalJSON ¶
func (r *SSHSession) UnmarshalJSON(data []byte) error
type SSHSessionCreateParams ¶
type SSHSessionCreateParams struct {
PublicKey string `json:"public_key" api:"required"`
WakeIfNeeded param.Opt[bool] `json:"wake_if_needed,omitzero"`
// contains filtered or unexported fields
}
The property PublicKey is required.
func (SSHSessionCreateParams) MarshalJSON ¶
func (r SSHSessionCreateParams) MarshalJSON() (data []byte, err error)
func (*SSHSessionCreateParams) UnmarshalJSON ¶
func (r *SSHSessionCreateParams) UnmarshalJSON(data []byte) error
type SSHSessionList ¶
type SSHSessionList struct {
Items []SSHSession `json:"items" api:"required"`
NextCursor string `json:"next_cursor"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
Items respjson.Field
NextCursor respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (SSHSessionList) RawJSON ¶
func (r SSHSessionList) RawJSON() string
Returns the unmodified JSON received from the API
func (*SSHSessionList) UnmarshalJSON ¶
func (r *SSHSessionList) UnmarshalJSON(data []byte) error
type SSHSessionStatus ¶
type SSHSessionStatus string
const ( SSHSessionStatusWakeInProgress SSHSessionStatus = "wake_in_progress" SSHSessionStatusReady SSHSessionStatus = "ready" SSHSessionStatusClosed SSHSessionStatus = "closed" SSHSessionStatusExpired SSHSessionStatus = "expired" SSHSessionStatusFailed SSHSessionStatus = "failed" )
type Terminal ¶
type Terminal struct {
CreatedAt time.Time `json:"created_at" api:"required" format:"date-time"`
Height int64 `json:"height" api:"required"`
// Any of "wake_in_progress", "ready", "closed", "expired", "failed".
Status TerminalStatus `json:"status" api:"required"`
TerminalID string `json:"terminal_id" api:"required"`
Width int64 `json:"width" api:"required"`
WorkspaceID string `json:"workspace_id" api:"required"`
ErrorCode string `json:"error_code"`
ErrorMessage string `json:"error_message"`
ExpiresAt time.Time `json:"expires_at" format:"date-time"`
// Any of "websocket".
Protocol TerminalProtocol `json:"protocol"`
ReadyAt time.Time `json:"ready_at" format:"date-time"`
RetryAfterMs int64 `json:"retry_after_ms"`
StreamURL string `json:"stream_url"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
CreatedAt respjson.Field
Height respjson.Field
Status respjson.Field
TerminalID respjson.Field
Width respjson.Field
WorkspaceID respjson.Field
ErrorCode respjson.Field
ErrorMessage respjson.Field
ExpiresAt respjson.Field
Protocol respjson.Field
ReadyAt respjson.Field
RetryAfterMs respjson.Field
StreamURL respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (*Terminal) UnmarshalJSON ¶
type TerminalCreateParams ¶
type TerminalCreateParams struct {
Height int64 `json:"height" api:"required"`
Width int64 `json:"width" api:"required"`
Cwd param.Opt[string] `json:"cwd,omitzero"`
Shell param.Opt[string] `json:"shell,omitzero"`
WakeIfNeeded param.Opt[bool] `json:"wake_if_needed,omitzero"`
Env map[string]string `json:"env,omitzero"`
// contains filtered or unexported fields
}
The properties Height, Width are required.
func (TerminalCreateParams) MarshalJSON ¶
func (r TerminalCreateParams) MarshalJSON() (data []byte, err error)
func (*TerminalCreateParams) UnmarshalJSON ¶
func (r *TerminalCreateParams) UnmarshalJSON(data []byte) error
type TerminalList ¶
type TerminalList struct {
Items []Terminal `json:"items" api:"required"`
NextCursor string `json:"next_cursor"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
Items respjson.Field
NextCursor respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (TerminalList) RawJSON ¶
func (r TerminalList) RawJSON() string
Returns the unmodified JSON received from the API
func (*TerminalList) UnmarshalJSON ¶
func (r *TerminalList) UnmarshalJSON(data []byte) error
type TerminalProtocol ¶
type TerminalProtocol string
const (
TerminalProtocolWebsocket TerminalProtocol = "websocket"
)
type TerminalStatus ¶
type TerminalStatus string
const ( TerminalStatusWakeInProgress TerminalStatus = "wake_in_progress" TerminalStatusReady TerminalStatus = "ready" TerminalStatusClosed TerminalStatus = "closed" TerminalStatusExpired TerminalStatus = "expired" TerminalStatusFailed TerminalStatus = "failed" )
type UpdateParams ¶
type UpdateParams struct {
// Memory in MiB.
MemoryMiB param.Opt[int64] `json:"memory_mib,omitzero"`
StorageGiB param.Opt[int64] `json:"storage_gib,omitzero"`
// CPU in vCPUs.
VCPU param.Opt[float64] `json:"vcpu,omitzero"`
// contains filtered or unexported fields
}
func (UpdateParams) MarshalJSON ¶
func (r UpdateParams) MarshalJSON() (data []byte, err error)
func (*UpdateParams) UnmarshalJSON ¶
func (r *UpdateParams) UnmarshalJSON(data []byte) error
type Workspace ¶
type Workspace struct {
// Any of "active", "inactive", "destroyed".
DesiredState WorkspaceDesiredState `json:"desired_state" api:"required"`
// Memory in MiB.
MemoryMiB int64 `json:"memory_mib" api:"required"`
Status LifecycleStatus `json:"status" api:"required"`
StorageGiB int64 `json:"storage_gib" api:"required"`
// CPU in vCPUs.
VCPU float64 `json:"vcpu" api:"required"`
WorkspaceID string `json:"workspace_id" api:"required"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
DesiredState respjson.Field
MemoryMiB respjson.Field
Status respjson.Field
StorageGiB respjson.Field
VCPU respjson.Field
WorkspaceID respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (*Workspace) UnmarshalJSON ¶
type WorkspaceArtifactDeleteParams ¶
type WorkspaceArtifactDeleteParams struct {
WorkspaceID string `path:"workspace_id" api:"required" json:"-"`
// contains filtered or unexported fields
}
type WorkspaceArtifactGetParams ¶
type WorkspaceArtifactGetParams struct {
WorkspaceID string `path:"workspace_id" api:"required" json:"-"`
// contains filtered or unexported fields
}
type WorkspaceArtifactListParams ¶
type WorkspaceArtifactListParams struct {
Cursor param.Opt[string] `query:"cursor,omitzero" json:"-"`
Limit param.Opt[int64] `query:"limit,omitzero" json:"-"`
// contains filtered or unexported fields
}
func (WorkspaceArtifactListParams) URLQuery ¶
func (r WorkspaceArtifactListParams) URLQuery() (v url.Values, err error)
URLQuery serializes WorkspaceArtifactListParams's query parameters as `url.Values`.
type WorkspaceArtifactService ¶
type WorkspaceArtifactService struct {
Options []option.RequestOption
}
WorkspaceArtifactService contains methods and other services that help with interacting with the Dedalus API.
Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewWorkspaceArtifactService method instead.
func NewWorkspaceArtifactService ¶
func NewWorkspaceArtifactService(opts ...option.RequestOption) (r WorkspaceArtifactService)
NewWorkspaceArtifactService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.
func (*WorkspaceArtifactService) Delete ¶
func (r *WorkspaceArtifactService) Delete(ctx context.Context, artifactID string, body WorkspaceArtifactDeleteParams, opts ...option.RequestOption) (res *Artifact, err error)
Delete artifact
func (*WorkspaceArtifactService) Get ¶
func (r *WorkspaceArtifactService) Get(ctx context.Context, artifactID string, query WorkspaceArtifactGetParams, opts ...option.RequestOption) (res *Artifact, err error)
Get artifact
func (*WorkspaceArtifactService) List ¶
func (r *WorkspaceArtifactService) List(ctx context.Context, workspaceID string, query WorkspaceArtifactListParams, opts ...option.RequestOption) (res *pagination.CursorPage[Artifact], err error)
List artifacts
func (*WorkspaceArtifactService) ListAutoPaging ¶
func (r *WorkspaceArtifactService) ListAutoPaging(ctx context.Context, workspaceID string, query WorkspaceArtifactListParams, opts ...option.RequestOption) *pagination.CursorPageAutoPager[Artifact]
List artifacts
type WorkspaceDeleteParams ¶
type WorkspaceDeleteParams struct {
IfMatch string `header:"If-Match" api:"required" json:"-"`
// contains filtered or unexported fields
}
type WorkspaceDesiredState ¶
type WorkspaceDesiredState string
const ( WorkspaceDesiredStateActive WorkspaceDesiredState = "active" WorkspaceDesiredStateInactive WorkspaceDesiredState = "inactive" WorkspaceDesiredStateDestroyed WorkspaceDesiredState = "destroyed" )
type WorkspaceExecutionDeleteParams ¶
type WorkspaceExecutionDeleteParams struct {
WorkspaceID string `path:"workspace_id" api:"required" json:"-"`
// contains filtered or unexported fields
}
type WorkspaceExecutionEventsParams ¶
type WorkspaceExecutionEventsParams struct {
WorkspaceID string `path:"workspace_id" api:"required" json:"-"`
Cursor param.Opt[string] `query:"cursor,omitzero" json:"-"`
Limit param.Opt[int64] `query:"limit,omitzero" json:"-"`
// contains filtered or unexported fields
}
func (WorkspaceExecutionEventsParams) URLQuery ¶
func (r WorkspaceExecutionEventsParams) URLQuery() (v url.Values, err error)
URLQuery serializes WorkspaceExecutionEventsParams's query parameters as `url.Values`.
type WorkspaceExecutionGetParams ¶
type WorkspaceExecutionGetParams struct {
WorkspaceID string `path:"workspace_id" api:"required" json:"-"`
// contains filtered or unexported fields
}
type WorkspaceExecutionListParams ¶
type WorkspaceExecutionListParams struct {
Cursor param.Opt[string] `query:"cursor,omitzero" json:"-"`
Limit param.Opt[int64] `query:"limit,omitzero" json:"-"`
// contains filtered or unexported fields
}
func (WorkspaceExecutionListParams) URLQuery ¶
func (r WorkspaceExecutionListParams) URLQuery() (v url.Values, err error)
URLQuery serializes WorkspaceExecutionListParams's query parameters as `url.Values`.
type WorkspaceExecutionNewParams ¶
type WorkspaceExecutionNewParams struct {
ExecutionCreateParams ExecutionCreateParams
// contains filtered or unexported fields
}
func (WorkspaceExecutionNewParams) MarshalJSON ¶
func (r WorkspaceExecutionNewParams) MarshalJSON() (data []byte, err error)
func (*WorkspaceExecutionNewParams) UnmarshalJSON ¶
func (r *WorkspaceExecutionNewParams) UnmarshalJSON(data []byte) error
type WorkspaceExecutionOutputParams ¶
type WorkspaceExecutionOutputParams struct {
WorkspaceID string `path:"workspace_id" api:"required" json:"-"`
// contains filtered or unexported fields
}
type WorkspaceExecutionService ¶
type WorkspaceExecutionService struct {
Options []option.RequestOption
}
WorkspaceExecutionService contains methods and other services that help with interacting with the Dedalus API.
Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewWorkspaceExecutionService method instead.
func NewWorkspaceExecutionService ¶
func NewWorkspaceExecutionService(opts ...option.RequestOption) (r WorkspaceExecutionService)
NewWorkspaceExecutionService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.
func (*WorkspaceExecutionService) Delete ¶
func (r *WorkspaceExecutionService) Delete(ctx context.Context, executionID string, body WorkspaceExecutionDeleteParams, opts ...option.RequestOption) (res *Execution, err error)
Delete execution
func (*WorkspaceExecutionService) Events ¶
func (r *WorkspaceExecutionService) Events(ctx context.Context, executionID string, params WorkspaceExecutionEventsParams, opts ...option.RequestOption) (res *pagination.CursorPage[ExecutionEvent], err error)
List execution events
func (*WorkspaceExecutionService) EventsAutoPaging ¶
func (r *WorkspaceExecutionService) EventsAutoPaging(ctx context.Context, executionID string, params WorkspaceExecutionEventsParams, opts ...option.RequestOption) *pagination.CursorPageAutoPager[ExecutionEvent]
List execution events
func (*WorkspaceExecutionService) Get ¶
func (r *WorkspaceExecutionService) Get(ctx context.Context, executionID string, query WorkspaceExecutionGetParams, opts ...option.RequestOption) (res *Execution, err error)
Get execution
func (*WorkspaceExecutionService) List ¶
func (r *WorkspaceExecutionService) List(ctx context.Context, workspaceID string, query WorkspaceExecutionListParams, opts ...option.RequestOption) (res *pagination.CursorPage[Execution], err error)
List executions
func (*WorkspaceExecutionService) ListAutoPaging ¶
func (r *WorkspaceExecutionService) ListAutoPaging(ctx context.Context, workspaceID string, query WorkspaceExecutionListParams, opts ...option.RequestOption) *pagination.CursorPageAutoPager[Execution]
List executions
func (*WorkspaceExecutionService) New ¶
func (r *WorkspaceExecutionService) New(ctx context.Context, workspaceID string, body WorkspaceExecutionNewParams, opts ...option.RequestOption) (res *Execution, err error)
Create execution
func (*WorkspaceExecutionService) Output ¶
func (r *WorkspaceExecutionService) Output(ctx context.Context, executionID string, query WorkspaceExecutionOutputParams, opts ...option.RequestOption) (res *ExecutionOutput, err error)
Get execution output
type WorkspaceList ¶
type WorkspaceList struct {
Items []WorkspaceListItem `json:"items" api:"required"`
NextCursor string `json:"next_cursor"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
Items respjson.Field
NextCursor respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (WorkspaceList) RawJSON ¶
func (r WorkspaceList) RawJSON() string
Returns the unmodified JSON received from the API
func (*WorkspaceList) UnmarshalJSON ¶
func (r *WorkspaceList) UnmarshalJSON(data []byte) error
type WorkspaceListItem ¶
type WorkspaceListItem struct {
CreatedAt time.Time `json:"created_at" api:"required" format:"date-time"`
// Any of "active", "inactive", "destroyed".
DesiredState string `json:"desired_state" api:"required"`
// Memory in MiB.
MemoryMiB int64 `json:"memory_mib" api:"required"`
Status LifecycleStatus `json:"status" api:"required"`
StorageGiB int64 `json:"storage_gib" api:"required"`
// CPU in vCPUs.
VCPU float64 `json:"vcpu" api:"required"`
WorkspaceID string `json:"workspace_id" api:"required"`
// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
JSON struct {
CreatedAt respjson.Field
DesiredState respjson.Field
MemoryMiB respjson.Field
Status respjson.Field
StorageGiB respjson.Field
VCPU respjson.Field
WorkspaceID respjson.Field
ExtraFields map[string]respjson.Field
// contains filtered or unexported fields
} `json:"-"`
}
func (WorkspaceListItem) RawJSON ¶
func (r WorkspaceListItem) RawJSON() string
Returns the unmodified JSON received from the API
func (*WorkspaceListItem) UnmarshalJSON ¶
func (r *WorkspaceListItem) UnmarshalJSON(data []byte) error
type WorkspaceListParams ¶
type WorkspaceListParams struct {
Cursor param.Opt[string] `query:"cursor,omitzero" json:"-"`
Limit param.Opt[int64] `query:"limit,omitzero" json:"-"`
// contains filtered or unexported fields
}
func (WorkspaceListParams) URLQuery ¶
func (r WorkspaceListParams) URLQuery() (v url.Values, err error)
URLQuery serializes WorkspaceListParams's query parameters as `url.Values`.
type WorkspaceNewParams ¶
type WorkspaceNewParams struct {
CreateParams CreateParams
// contains filtered or unexported fields
}
func (WorkspaceNewParams) MarshalJSON ¶
func (r WorkspaceNewParams) MarshalJSON() (data []byte, err error)
func (*WorkspaceNewParams) UnmarshalJSON ¶
func (r *WorkspaceNewParams) UnmarshalJSON(data []byte) error
type WorkspacePreviewDeleteParams ¶
type WorkspacePreviewDeleteParams struct {
WorkspaceID string `path:"workspace_id" api:"required" json:"-"`
// contains filtered or unexported fields
}
type WorkspacePreviewGetParams ¶
type WorkspacePreviewGetParams struct {
WorkspaceID string `path:"workspace_id" api:"required" json:"-"`
// contains filtered or unexported fields
}
type WorkspacePreviewListParams ¶
type WorkspacePreviewListParams struct {
Cursor param.Opt[string] `query:"cursor,omitzero" json:"-"`
Limit param.Opt[int64] `query:"limit,omitzero" json:"-"`
// contains filtered or unexported fields
}
func (WorkspacePreviewListParams) URLQuery ¶
func (r WorkspacePreviewListParams) URLQuery() (v url.Values, err error)
URLQuery serializes WorkspacePreviewListParams's query parameters as `url.Values`.
type WorkspacePreviewNewParams ¶
type WorkspacePreviewNewParams struct {
PreviewCreateParams PreviewCreateParams
// contains filtered or unexported fields
}
func (WorkspacePreviewNewParams) MarshalJSON ¶
func (r WorkspacePreviewNewParams) MarshalJSON() (data []byte, err error)
func (*WorkspacePreviewNewParams) UnmarshalJSON ¶
func (r *WorkspacePreviewNewParams) UnmarshalJSON(data []byte) error
type WorkspacePreviewService ¶
type WorkspacePreviewService struct {
Options []option.RequestOption
}
WorkspacePreviewService contains methods and other services that help with interacting with the Dedalus API.
Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewWorkspacePreviewService method instead.
func NewWorkspacePreviewService ¶
func NewWorkspacePreviewService(opts ...option.RequestOption) (r WorkspacePreviewService)
NewWorkspacePreviewService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.
func (*WorkspacePreviewService) Delete ¶
func (r *WorkspacePreviewService) Delete(ctx context.Context, previewID string, body WorkspacePreviewDeleteParams, opts ...option.RequestOption) (res *Preview, err error)
Delete preview
func (*WorkspacePreviewService) Get ¶
func (r *WorkspacePreviewService) Get(ctx context.Context, previewID string, query WorkspacePreviewGetParams, opts ...option.RequestOption) (res *Preview, err error)
Get preview
func (*WorkspacePreviewService) List ¶
func (r *WorkspacePreviewService) List(ctx context.Context, workspaceID string, query WorkspacePreviewListParams, opts ...option.RequestOption) (res *pagination.CursorPage[Preview], err error)
List previews
func (*WorkspacePreviewService) ListAutoPaging ¶
func (r *WorkspacePreviewService) ListAutoPaging(ctx context.Context, workspaceID string, query WorkspacePreviewListParams, opts ...option.RequestOption) *pagination.CursorPageAutoPager[Preview]
List previews
func (*WorkspacePreviewService) New ¶
func (r *WorkspacePreviewService) New(ctx context.Context, workspaceID string, body WorkspacePreviewNewParams, opts ...option.RequestOption) (res *Preview, err error)
Create preview
type WorkspaceSSHDeleteParams ¶
type WorkspaceSSHDeleteParams struct {
WorkspaceID string `path:"workspace_id" api:"required" json:"-"`
// contains filtered or unexported fields
}
type WorkspaceSSHGetParams ¶
type WorkspaceSSHGetParams struct {
WorkspaceID string `path:"workspace_id" api:"required" json:"-"`
// contains filtered or unexported fields
}
type WorkspaceSSHListParams ¶
type WorkspaceSSHListParams struct {
Cursor param.Opt[string] `query:"cursor,omitzero" json:"-"`
Limit param.Opt[int64] `query:"limit,omitzero" json:"-"`
// contains filtered or unexported fields
}
func (WorkspaceSSHListParams) URLQuery ¶
func (r WorkspaceSSHListParams) URLQuery() (v url.Values, err error)
URLQuery serializes WorkspaceSSHListParams's query parameters as `url.Values`.
type WorkspaceSSHNewParams ¶
type WorkspaceSSHNewParams struct {
SSHSessionCreateParams SSHSessionCreateParams
// contains filtered or unexported fields
}
func (WorkspaceSSHNewParams) MarshalJSON ¶
func (r WorkspaceSSHNewParams) MarshalJSON() (data []byte, err error)
func (*WorkspaceSSHNewParams) UnmarshalJSON ¶
func (r *WorkspaceSSHNewParams) UnmarshalJSON(data []byte) error
type WorkspaceSSHService ¶
type WorkspaceSSHService struct {
Options []option.RequestOption
}
WorkspaceSSHService contains methods and other services that help with interacting with the Dedalus API.
Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewWorkspaceSSHService method instead.
func NewWorkspaceSSHService ¶
func NewWorkspaceSSHService(opts ...option.RequestOption) (r WorkspaceSSHService)
NewWorkspaceSSHService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.
func (*WorkspaceSSHService) Delete ¶
func (r *WorkspaceSSHService) Delete(ctx context.Context, sessionID string, body WorkspaceSSHDeleteParams, opts ...option.RequestOption) (res *SSHSession, err error)
Delete SSH session
func (*WorkspaceSSHService) Get ¶
func (r *WorkspaceSSHService) Get(ctx context.Context, sessionID string, query WorkspaceSSHGetParams, opts ...option.RequestOption) (res *SSHSession, err error)
Get SSH session
func (*WorkspaceSSHService) List ¶
func (r *WorkspaceSSHService) List(ctx context.Context, workspaceID string, query WorkspaceSSHListParams, opts ...option.RequestOption) (res *pagination.CursorPage[SSHSession], err error)
List SSH sessions
func (*WorkspaceSSHService) ListAutoPaging ¶
func (r *WorkspaceSSHService) ListAutoPaging(ctx context.Context, workspaceID string, query WorkspaceSSHListParams, opts ...option.RequestOption) *pagination.CursorPageAutoPager[SSHSession]
List SSH sessions
func (*WorkspaceSSHService) New ¶
func (r *WorkspaceSSHService) New(ctx context.Context, workspaceID string, body WorkspaceSSHNewParams, opts ...option.RequestOption) (res *SSHSession, err error)
Create SSH session
type WorkspaceService ¶
type WorkspaceService struct {
Options []option.RequestOption
Artifacts WorkspaceArtifactService
Previews WorkspacePreviewService
SSH WorkspaceSSHService
Executions WorkspaceExecutionService
Terminals WorkspaceTerminalService
}
WorkspaceService contains methods and other services that help with interacting with the Dedalus API.
Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewWorkspaceService method instead.
func NewWorkspaceService ¶
func NewWorkspaceService(opts ...option.RequestOption) (r WorkspaceService)
NewWorkspaceService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.
func (*WorkspaceService) Delete ¶
func (r *WorkspaceService) Delete(ctx context.Context, workspaceID string, body WorkspaceDeleteParams, opts ...option.RequestOption) (res *Workspace, err error)
Destroy workspace
func (*WorkspaceService) Get ¶
func (r *WorkspaceService) Get(ctx context.Context, workspaceID string, opts ...option.RequestOption) (res *Workspace, err error)
Get workspace
func (*WorkspaceService) List ¶
func (r *WorkspaceService) List(ctx context.Context, query WorkspaceListParams, opts ...option.RequestOption) (res *pagination.CursorPage[WorkspaceListItem], err error)
List workspaces
func (*WorkspaceService) ListAutoPaging ¶
func (r *WorkspaceService) ListAutoPaging(ctx context.Context, query WorkspaceListParams, opts ...option.RequestOption) *pagination.CursorPageAutoPager[WorkspaceListItem]
List workspaces
func (*WorkspaceService) New ¶
func (r *WorkspaceService) New(ctx context.Context, body WorkspaceNewParams, opts ...option.RequestOption) (res *Workspace, err error)
Create workspace
func (*WorkspaceService) Update ¶
func (r *WorkspaceService) Update(ctx context.Context, workspaceID string, params WorkspaceUpdateParams, opts ...option.RequestOption) (res *Workspace, err error)
Update workspace
type WorkspaceTerminalDeleteParams ¶
type WorkspaceTerminalDeleteParams struct {
WorkspaceID string `path:"workspace_id" api:"required" json:"-"`
// contains filtered or unexported fields
}
type WorkspaceTerminalGetParams ¶
type WorkspaceTerminalGetParams struct {
WorkspaceID string `path:"workspace_id" api:"required" json:"-"`
// contains filtered or unexported fields
}
type WorkspaceTerminalListParams ¶
type WorkspaceTerminalListParams struct {
Cursor param.Opt[string] `query:"cursor,omitzero" json:"-"`
Limit param.Opt[int64] `query:"limit,omitzero" json:"-"`
// contains filtered or unexported fields
}
func (WorkspaceTerminalListParams) URLQuery ¶
func (r WorkspaceTerminalListParams) URLQuery() (v url.Values, err error)
URLQuery serializes WorkspaceTerminalListParams's query parameters as `url.Values`.
type WorkspaceTerminalNewParams ¶
type WorkspaceTerminalNewParams struct {
TerminalCreateParams TerminalCreateParams
// contains filtered or unexported fields
}
func (WorkspaceTerminalNewParams) MarshalJSON ¶
func (r WorkspaceTerminalNewParams) MarshalJSON() (data []byte, err error)
func (*WorkspaceTerminalNewParams) UnmarshalJSON ¶
func (r *WorkspaceTerminalNewParams) UnmarshalJSON(data []byte) error
type WorkspaceTerminalService ¶
type WorkspaceTerminalService struct {
Options []option.RequestOption
}
WorkspaceTerminalService contains methods and other services that help with interacting with the Dedalus API.
Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewWorkspaceTerminalService method instead.
func NewWorkspaceTerminalService ¶
func NewWorkspaceTerminalService(opts ...option.RequestOption) (r WorkspaceTerminalService)
NewWorkspaceTerminalService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.
func (*WorkspaceTerminalService) Delete ¶
func (r *WorkspaceTerminalService) Delete(ctx context.Context, terminalID string, body WorkspaceTerminalDeleteParams, opts ...option.RequestOption) (res *Terminal, err error)
Delete terminal
func (*WorkspaceTerminalService) Get ¶
func (r *WorkspaceTerminalService) Get(ctx context.Context, terminalID string, query WorkspaceTerminalGetParams, opts ...option.RequestOption) (res *Terminal, err error)
Get terminal
func (*WorkspaceTerminalService) List ¶
func (r *WorkspaceTerminalService) List(ctx context.Context, workspaceID string, query WorkspaceTerminalListParams, opts ...option.RequestOption) (res *pagination.CursorPage[Terminal], err error)
List terminals
func (*WorkspaceTerminalService) ListAutoPaging ¶
func (r *WorkspaceTerminalService) ListAutoPaging(ctx context.Context, workspaceID string, query WorkspaceTerminalListParams, opts ...option.RequestOption) *pagination.CursorPageAutoPager[Terminal]
List terminals
func (*WorkspaceTerminalService) New ¶
func (r *WorkspaceTerminalService) New(ctx context.Context, workspaceID string, body WorkspaceTerminalNewParams, opts ...option.RequestOption) (res *Terminal, err error)
Create terminal
type WorkspaceUpdateParams ¶
type WorkspaceUpdateParams struct {
UpdateParams UpdateParams
IfMatch string `header:"If-Match" api:"required" json:"-"`
// contains filtered or unexported fields
}
func (WorkspaceUpdateParams) MarshalJSON ¶
func (r WorkspaceUpdateParams) MarshalJSON() (data []byte, err error)
func (*WorkspaceUpdateParams) UnmarshalJSON ¶
func (r *WorkspaceUpdateParams) UnmarshalJSON(data []byte) error
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
encoding/json
Package json implements encoding and decoding of JSON as defined in RFC 7159.
|
Package json implements encoding and decoding of JSON as defined in RFC 7159. |
|
encoding/json/shims
This package provides shims over Go 1.2{2,3} APIs which are missing from Go 1.22, and used by the Go 1.24 encoding/json package.
|
This package provides shims over Go 1.2{2,3} APIs which are missing from Go 1.22, and used by the Go 1.24 encoding/json package. |
|
packages
|
|
|
shared
|
|